@@ -392,75 +392,75 @@ char *header;
 
 #define pir_data_tab	16
 
-/* pir Flat-file format:    (lines are prepended with '|' to keep cpp happy)
-|ENTRY           CCHU       #Type Protein
+/* pir Flat-file format:
+ENTRY           CCHU       #Type Protein
 12345678901234567890123456789012345678901234567890123456789012345678901234567890
 .........1.........2.........3.........4.........5.........6.........7.........8
 all data starts at tab=17 or further
 
-|ENTRY       blah	<< Start entry, index it
-|TITLE	    blah   	<< Index def line == HEADER line
-|ACCESSION   blah	<< Index acc line
-|KEYWORDS    blah	<< index keywords
-|SOURCE      blah	<< index source
-|REFERENCE   blah	<< Index
-|SUPERFAMILY blah	<< Index
-|            blah	<< Index
-|ANYOTHERS	jazz	<< skipit
-|any word starting w/ "#", skipit
-|///  				<< end of entry == entry separator
-|ENTRY           CCHU       #Type Protein
-|TITLE           Cytochrome c - Human
-|DATE            #Sequence 30-Sep-1991 #Text 30-Sep-1991
-|PLACEMENT          1.0    1.0    1.0    1.0    1.0
-|SOURCE          Homo sapiens #Common-name man
-|ACCESSION       A31764\ A05676\ A00001
-|REFERENCE
-|   #Authors     Evans M.J., Scarpulla R.C.
-|   #Journal     Proc. Natl. Acad. Sci. U.S.A. (1988) 85:9625-9629
-|   #Title       The human somatic cytochrome c gene: two classes of
-|                  processed pseudogenes demarcate a period of rapid
-|                  molecular evolution.
-|   #Reference-number A31764
-|   #Accession   A31764
-|   #Molecule-type DNA
-|   #Residues    1-105 <EVA>
-|   #Cross-reference GB:M22877
-|REFERENCE
-|   #Authors     Matsubara H., Smith E.L.
-|   #Journal     J. Biol. Chem. (1963) 238:2732-2753
-|   #Reference-number A05676
-|   #Accession   A05676
-|   #Molecule-type protein
-|   #Residues    2-28;29-46;47-100;101-105 <MATS>
-|REFERENCE
-|   #Authors     Matsubara H., Smith E.L.
-|   #Journal     J. Biol. Chem. (1962) 237:3575-3576
-|   #Reference-number A00001
-|   #Comment     66-Leu is found in 10% of the molecules in pooled
-|                  protein.
-|GENETIC
-|   #Introns        57/1
-|SUPERFAMILY     #Name cytochrome c
-|KEYWORDS        acetylation\ electron transport\ heme\
-|                  mitochondrion\ oxidative phosphorylation\
-|                  polymorphism\ respiratory chain
-|FEATURE
-|   2-105                   #Protein cytochrome c (experimental)
-|                             <MAT>\
-|   2                       #Modified-site acetylated amino end
-|                             (experimental)\
-|   15,18                   #Binding-site heme (covalent)\
-|   19,81                   #Binding-site heme iron (axial ligands)
-|SUMMARY       #Molecular-weight 11749  #Length 105  #Checksum  3247
-|SEQUENCE
-|                5        10        15        20        25        30
-|      1 M G D V E K G K K I F I M K C S Q C H T V E K G G K H K T G
-|     31 P N L H G L F G R K T G Q A P G Y S Y T A A N K N K G I I W
-|     61 G E D T L M E Y L E N P K K Y I P G T K M I F V G I K K K E
-|     91 E R A D L I A Y L K K A T N E
-|///
-|
+ENTRY       blah	<< Start entry, index it
+TITLE	    blah   	<< Index def line == HEADER line
+ACCESSION   blah	<< Index acc line
+KEYWORDS    blah	<< index keywords
+SOURCE      blah	<< index source
+REFERENCE   blah	<< Index
+SUPERFAMILY blah	<< Index
+            blah	<< Index
+ANYOTHERS	jazz	<< skipit
+any word starting w/ "#", skipit
+///  				<< end of entry == entry separator
+ENTRY           CCHU       #Type Protein
+TITLE           Cytochrome c - Human
+DATE            #Sequence 30-Sep-1991 #Text 30-Sep-1991
+PLACEMENT          1.0    1.0    1.0    1.0    1.0
+SOURCE          Homo sapiens #Common-name man
+ACCESSION       A31764\ A05676\ A00001
+REFERENCE
+   #Authors     Evans M.J., Scarpulla R.C.
+   #Journal     Proc. Natl. Acad. Sci. U.S.A. (1988) 85:9625-9629
+   #Title       The human somatic cytochrome c gene: two classes of
+                  processed pseudogenes demarcate a period of rapid
+                  molecular evolution.
+   #Reference-number A31764
+   #Accession   A31764
+   #Molecule-type DNA
+   #Residues    1-105 <EVA>
+   #Cross-reference GB:M22877
+REFERENCE
+   #Authors     Matsubara H., Smith E.L.
+   #Journal     J. Biol. Chem. (1963) 238:2732-2753
+   #Reference-number A05676
+   #Accession   A05676
+   #Molecule-type protein
+   #Residues    2-28;29-46;47-100;101-105 <MATS>
+REFERENCE
+   #Authors     Matsubara H., Smith E.L.
+   #Journal     J. Biol. Chem. (1962) 237:3575-3576
+   #Reference-number A00001
+   #Comment     66-Leu is found in 10% of the molecules in pooled
+                  protein.
+GENETIC
+   #Introns        57/1
+SUPERFAMILY     #Name cytochrome c
+KEYWORDS        acetylation\ electron transport\ heme\
+                  mitochondrion\ oxidative phosphorylation\
+                  polymorphism\ respiratory chain
+FEATURE
+   2-105                   #Protein cytochrome c (experimental)
+                             <MAT>\
+   2                       #Modified-site acetylated amino end
+                             (experimental)\
+   15,18                   #Binding-site heme (covalent)\
+   19,81                   #Binding-site heme iron (axial ligands)
+SUMMARY       #Molecular-weight 11749  #Length 105  #Checksum  3247
+SEQUENCE
+                5        10        15        20        25        30
+      1 M G D V E K G K K I F I M K C S Q C H T V E K G G K H K T G
+     31 P N L H G L F G R K T G Q A P G Y S Y T A A N K N K G I I W
+     61 G E D T L M E Y L E N P K K Y I P G T K M I F V G I K K K E
+     91 E R A D L I A Y L K K A T N E
+///
+
 *****/
 
 
@@ -1073,19 +1073,19 @@ char *header;
  */
 
 /*------ example
-|#Abnormal:  see A
-|#abnormal abdomen:  see a( )
-|#Abnormal abdomen:  see A
-|# abnormal eye:  see mit15
-|#abnormal oocytes:  see abo
-|#abnormal tergites:  see abt
-|#abnormal wings:  see abw
-|#abo:  abnormal oocyte
-| location:  2-44.0 (mapped with respect to J, 2-41).
-| origin:  Naturally occurring allele recovered near Rome,
-|   Italy.
-| references:  Sandler, Lindsley, Nicoletti, and Trippa,
-| ...
+#Abnormal:  see A
+#abnormal abdomen:  see a( )
+#Abnormal abdomen:  see A
+# abnormal eye:  see mit15
+#abnormal oocytes:  see abo
+#abnormal tergites:  see abt
+#abnormal wings:  see abw
+#abo:  abnormal oocyte
+ location:  2-44.0 (mapped with respect to J, 2-41).
+ origin:  Naturally occurring allele recovered near Rome,
+   Italy.
+ references:  Sandler, Lindsley, Nicoletti, and Trippa,
+ ...
 ----*/
 
 
@@ -2071,65 +2071,6 @@ char *header;
   }
   para_header[0] = 0;
 }  
-/* ========================================
- * ===  INRIA DOC   Customizations     ====
- * a la netnews
- * ========================================
- */
-
-/* ottavj@sophia.inria.fr
-Inria Documents are produced by a texto query, each on a separate file
-*/
-char inriadoc_title[MAX_HEADER_LEN + 1];
-char inriadoc_auth[MAX_HEADER_LEN + 1];
-
-void inriadoc_header_function(line)
-char *line;
-{
-  if((strlen(line) > strlen("Titre         ")) &&
-     substrcmp(line, "Titre         ") &&
-     (strlen(inriadoc_title) == 0)){
-    strcpy(inriadoc_title, " : ");
-    s_strncat(inriadoc_title, line + strlen("Titre           "), MAX_HEADER_LEN,
- MAX_HEADER_LEN);
-    trim_trailing_newline(inriadoc_title);
-     }
-  else if((strlen(line) > strlen("Auteur(s)     ")) &&
-     substrcmp(line, "Auteur(s)     ") &&
-     (strlen(inriadoc_auth) == 0)){
-    strncpy(inriadoc_auth, line + strlen("Auteur(s)     "), MAX_HEADER_LEN);
-    trim_trailing_newline(inriadoc_auth);
-     }
-}
-
-void inriadoc_finish_header_function(header)
-char *header;
-{
-  if(strlen(inriadoc_title) != 0 &&
-     strlen(inriadoc_auth) != 0){
-    /* trim the auth line if needed */
-    if(strlen(inriadoc_auth) > 40){
-      inriadoc_auth[40] = '\0';
-    }
-    strncpy(header, inriadoc_auth, MAX_HEADER_LEN);
-    s_strncat(header, " ", MAX_HEADER_LEN, MAX_HEADER_LEN);
-    s_strncat(header, inriadoc_title, MAX_HEADER_LEN, MAX_HEADER_LEN);
-    /* printf("%s\n", header); */
-     }
-  else if(strlen(inriadoc_title) != 0){
-    strncpy(header, inriadoc_title, MAX_HEADER_LEN);
-  }
-  else if(strlen(inriadoc_auth) != 0){
-    strncpy(header, inriadoc_auth, MAX_HEADER_LEN);
-  }
-  else{
-    strcpy(header, "Unknown Title");
-  }
-  inriadoc_auth[0] = '\0';
-  inriadoc_title[0] = '\0';
-}
-
-
 
 /* ==========================
  * ===  Seeker Separator  ===
@@ -2530,40 +2471,7 @@ char *header;
   refer_title[0] = '\0';
 }
 
-/* ===========================================
- * ===    HTML - grab the header from <TITLE></TITLE>
- * Michael Nelson (m.l.nelson@larc.nasa.gov) 10/26/93
- * ===========================================
- */
-  
-char html_header[MAX_HEADER_LEN +1];
-  
-boolean html_separator_function(line)
-char *line;
-{
-  return false;
-}
-  
-void html_header_function(line)
-char *line;
-{
-  if((strlen(line) > strlen("<TITLE>")) &&
-     ((substrcmp(line, "<TITLE>")) || (substrcmp(line, "<title>")))){
-    strncpy(html_header, line + strlen("<TITLE>"), MAX_HEADER_LEN);
-  }
-}
 
-void html_finish_header_function(header)
-char *header;
-{
-  if (strlen(html_header) == 0) {
-    strcpy(header, "No Title");
-  }
-  else {
-    s_strncpy(header, html_header, MAX_HEADER_LEN);
-  }
-  html_header[0] = 0;
-}  
 
 
 /* ===========================================
@@ -2729,6 +2637,7 @@ char *header;
  */
 
 
+#ifdef NeXT /* only do this if it is on a NeXT */
 
 /*----------------------- FSA -------------------*/
 #define fsa_max_edges 4
@@ -2901,7 +2810,7 @@ int input;
 		if((wobjc_header_end - wobjc_header)<(MAX_HEADER_LEN-5)
 		    && !(strchr(WOBJC_BLANK, *(wobjc_header_end-1))
 			&& strchr(WOBJC_BLANK, input)))
-		    { *wobjc_header_end++ = input; *wobjc_header_end = 0; }
+		    { *wobjc_header_end+= input; *wobjc_header_end = 0; }
 	    }
 	    
 
@@ -2916,10 +2825,10 @@ int input;
 		    || (wobjc_context==14 && !wobjc_header_end))
 		    wobjc_header_end = wobjc_header;
 		if((wobjc_class_end - wobjc_class_end)<(MAX_HEADER_LEN/2))
-		    { *wobjc_class_end++ = input; *wobjc_class_end = 0; }
+		    { *wobjc_class_end+= input; *wobjc_class_end = 0; }
 		if((wobjc_context==13 || wobjc_context==14)
 		    && (wobjc_header_end-wobjc_header_end)<(MAX_HEADER_LEN/2))
-		    { *wobjc_header_end++ = input; *wobjc_header_end = 0; }
+		    { *wobjc_header_end+= input; *wobjc_header_end = 0; }
 	    }
 	}
 	
@@ -2982,7 +2891,7 @@ char *header;
     /* Flush terminal blanks and balance opening '[' if any. */
     for(p=wobjc_header+strlen(wobjc_header);
     	p>wobjc_header && strchr(WOBJC_BLANK, *(p-1)); p--);
-    if(wobjc_header[0]=='+' || wobjc_header[0]=='-') *p++ = ']';
+    if(wobjc_header[0]=='+' || wobjc_header[0]=='-') *p+= ']';
     *p = 0;
     
 
@@ -2993,6 +2902,8 @@ char *header;
     return;
 }
 
+#endif /* def NeXT */
+
 
 /* ==============================
  * ===  Ziff computer select  ===
@@ -3064,425 +2975,6 @@ char* header;
   s_strncpy(header, p, MAX_HEADER_LEN);
 }
 
-#ifdef BIBDB
-/* ============================
- * ===  Bibdb Separator  ===
- * ============================
- */
-
-
-/*
- * formfedd seperate entries
- * each page is one entry
- */
-
-boolean bibdb_hit_header = 0;
-
-boolean bibdb_separator_function(line)
-char *line;
-{
-  if((strlen(line) < 3) && substrcmp(line,"")){
-    return(true);
-  }
-  else{
-    return(false);
-  }
-}
-
-char bibdb_header[MAX_HEADER_LEN + 1];
-
-void bibdb_header_function(line)
-char *line;
-{
-
-  /*
-  printf("bibdb_header_function: %s %d %d %d\n", line, bibdb_hit_header,
-	 bibdb_separator_function(line), strncmp(line, "CK: ", 4)); 
-	 */
-  if((bibdb_hit_header<2)
-     && (!bibdb_separator_function(line)))
-    if (!strncmp(line, "CK: ", 4)) {
-      strncpy(bibdb_header, line+4, MAX_HEADER_LEN);
-      bibdb_hit_header++;
-    } else if (!strncmp(line, "TI: ", 4)) {
-      int i;
-      for (i=0;i<21;i++) if (!bibdb_header[i]) bibdb_header[i]=' ';
-      strncpy(&(bibdb_header[20]), line+4, MAX_HEADER_LEN-21);
-      bibdb_hit_header++;
-    }
-}
-
-void bibdb_finish_header_function(header)
-char *header;
-
-{
-  bibdb_hit_header = 0; /* turn on the flag */
-  if (strlen(bibdb_header) == 0) {
-    strcpy(header, "No Title");
-  }
-  else {
-    strncpy(header, bibdb_header, MAX_HEADER_LEN);
-  }
-  bibdb_header[0] = '\0';
-}
-
-long bgetdate(s)
-     char *s;
-{
-  int year, month, day;
-  sscanf(s,"%2d%2d%2d", &year, &month, &day);
-  return (10000 * year + 100 * month + day);
-}
-
-long bibdb_date_function(line)
-char *line;
-{
-  if((strlen(line) > strlen("ED: ")) &&
-     substrcmp(line, "ED: ")){
-    return(bgetdate(line+4));
-  }
-  else return -1;
-}
-
-/* ============================
- * ===  Formfeed Separator  ===
- * ============================
- */
-
-
-/*
- * formfeed-seperate entries
- * each page is one entry
- */
-
-boolean formfeed_hit_header = false;
-
-boolean formfeed_separator_function(line)
-char *line;
-{
-  if((strlen(line) < 3) && substrcmp(line,"")){
-    /* printf("hit %s\n", line); */
-    return(true);
-  }
-  else{
-    return(false);
-  }
-}
-
-char formfeed_header[MAX_HEADER_LEN + 1];
-
-void formfeed_header_function(line)
-char *line;
-{
-  if(formfeed_hit_header
-     && (!formfeed_separator_function(line))
-     && strlen(formfeed_header) == 0) {
-    strncpy(formfeed_header, line, MAX_HEADER_LEN);
-    formfeed_hit_header = false;
-  }
-}
-
-void formfeed_finish_header_function(header)
-char *header;
-
-{
-  formfeed_hit_header = true; /* turn on the flag */
-  if (strlen(formfeed_header) == 0) {
-    strcpy(header, "No Title");
-  }
-  else {
-    strncpy(header, formfeed_header, MAX_HEADER_LEN);
-  }
-  formfeed_header[0] = '\0';
-}
-
-
-
-/* ==============================
- * ===  Bibinf Separator ===
- * ==============================
- */
-
-/* each section is one entry */
-
-int bibinf_hit_header = 0;
-
-boolean bibinf_separator_function(line)
-char *line;
-{
-  if((strlen(line) < 3) &&  ((*line == '\n')
-     || (*line == '\0'))) {
-    return(true);
-  }
-  else{
-    return(false);
-  }
-}
-
-#ifdef SIMPLE_BIBINF
-char bibinf_autor[MAX_HEADER_LEN + 1];
-char bibinf_title[MAX_HEADER_LEN + 1];
-
-void bibinf_header_function(line)
-char *line;
-{
-
-  if((bibinf_hit_header<2)
-     && (!bibinf_separator_function(line))) {
-    if (!strncmp(line, "Titel: ", 7)) {
-      strncpy(bibinf_title, line+7, MAX_HEADER_LEN);
-      bibinf_hit_header++;
-    } else if (!strncmp(line, "Autor: ", 7)) {
-      strncpy(bibinf_autor, line+7, MAX_HEADER_LEN);
-      bibinf_hit_header++;
-    }
-  }
-}
-void bibinf_finish_header_function(header)
-char *header;
-
-{
-  if (bibinf_hit_header == 0) {
-    strcpy(header, "No Title");
-  }
-  else {
-    int i;
-    if (strlen(bibinf_autor)>0) {
-      strncpy(header, bibinf_autor, 25);
-    } else {
-      strncpy(header, "No author given",  25);
-    }
-    for (i=strlen(header);i<MAX_HEADER_LEN;header[i++]=' ');
-    if (strlen(bibinf_title)>0) {
-      strncpy(&(header[26]), bibinf_title, MAX_HEADER_LEN-26);
-    } else {
-      strncpy(&(header[26]), "No title given",  MAX_HEADER_LEN-26);
-    }
-  bibinf_hit_header = 0; /* turn on the flag */
-  }
-  bibinf_autor[0] = '\0';
-  bibinf_title[0] = '\0';
-}
-
-#else
-
-char bibinf_header[MAX_HEADER_LEN + 1];
-boolean titel = false;
-boolean autor = false;
-boolean hrsgb = false;
-
-void bibinf_header_function(line)
-char *line;
-{
-  char *word;
-  char bibinf_header_copy[30];
-  int i;
-
-  if(bibinf_hit_header            /* begin of Autor-line */
-     && (!bibinf_separator_function(line))
-     && (!strncmp(line, "Autor: ", 7))){
-    s_strncpy(bibinf_header_copy, line+7, 26);
-    word = strtok(bibinf_header_copy," ");
-    while(word){
-      if(isalnum(*word)){
-        trim_trailing_newline(word);
-        s_strncat(bibinf_header,word,26,26);
-        s_strncat(bibinf_header," ",26,26);
-      }
-      else if(word[0] == '|'){
-        bibinf_header[strlen(bibinf_header)-1] = '\0';
-        s_strncat(bibinf_header,"; ",26,26);
-      } 
-      word = strtok(NULL," ");
-    }
-    autor = true;
-  }
-  else if(autor && bibinf_hit_header     /* next words of Autor-line */
-          && (!bibinf_separator_function(line))
-          && (strchr(line, ':') == NULL)){
-    s_strncpy(bibinf_header_copy, line, 26);
-    word = strtok(bibinf_header_copy," ");
-    while(word){
-      if(isalnum(*word)){
-        trim_trailing_newline(word);
-        s_strncat(bibinf_header,word,26,26);
-        s_strncat(bibinf_header," ",26,26);
-      }
-      else if(word[0] == '|'){
-        bibinf_header[strlen(bibinf_header)-1] = '\0';
-        s_strncat(bibinf_header,"; ",26,26);
-      } 
-      word = strtok(NULL," ");
-    }
-  }                            /* end of Autor-line */
-                               /* begin of Herausgeber-line */
-  else if(bibinf_hit_header
-          && (!bibinf_separator_function(line))
-          && (!strncmp(line, "Herausgeber: ", strlen("Herausgeber: ")))){
-    s_strncpy(bibinf_header_copy, line+strlen("Herausgeber: "), 26);
-    word = strtok(bibinf_header_copy," ");
-    while(word){
-      if(isalnum(*word)){
-        trim_trailing_newline(word);
-        s_strncat(bibinf_header,word,26,26);
-        s_strncat(bibinf_header," ",26,26);
-      }
-      else if(word[0] == '|'){
-        bibinf_header[strlen(bibinf_header)-1] = '\0';
-        s_strncat(bibinf_header,"; ",26,26);
-      }
-      word = strtok(NULL," ");
-    }
-    hrsgb = true;
-  }
-  else if(hrsgb && bibinf_hit_header      /* next words of Hrsgb-line */
-          && (!bibinf_separator_function(line))
-          && (strchr(line, ':') == NULL)){
-    s_strncpy(bibinf_header_copy, line, 26);
-    word = strtok(bibinf_header_copy," ");
-    while(word){
-      if(isalnum(*word)){
-        trim_trailing_newline(word);
-        s_strncat(bibinf_header,word,26,26);
-        s_strncat(bibinf_header," ",26,26);
-      }
-      else if(word[0] == '|'){
-        bibinf_header[strlen(bibinf_header)-1] = '\0';
-        s_strncat(bibinf_header,"; ",26,26);
-      } 
-      word = strtok(NULL," ");
-    }
-  }                       /* end of Hrsgb-line */
-
-  else if(bibinf_hit_header          /* begin of Titel-line */
-          && (!bibinf_separator_function(line))
-          && (!strncmp(line, "Titel: ", 7))) {
-    autor = false;
-    hrsgb = false;
-    for(i=strlen(bibinf_header); i < 25; i++)
-      s_strncat(bibinf_header," ",MAX_HEADER_LEN,MAX_HEADER_LEN);
-    s_strncat(bibinf_header,": ",MAX_HEADER_LEN,MAX_HEADER_LEN);
-    s_strncat(bibinf_header, line+7,MAX_HEADER_LEN,MAX_HEADER_LEN);
-    titel = true;
-  }
-  else if                           /* next words of Titel-line */
-    (titel && bibinf_hit_header
-     && (!bibinf_separator_function(line))
-     && (strchr(line, ':') == NULL)){
-      trim_trailing_newline(bibinf_header);
-      for(i=strlen(bibinf_header) - 1; isspace(bibinf_header[i]); i--)
-        bibinf_header[i] = '\0'; 
-      s_strncat(bibinf_header," ",MAX_HEADER_LEN,MAX_HEADER_LEN);
-      s_strncat(bibinf_header,line,MAX_HEADER_LEN,MAX_HEADER_LEN);
-      if(strlen(bibinf_header) == MAX_HEADER_LEN -1)
-        bibinf_header[MAX_HEADER_LEN-2] = '\n'; 
-    }
-  else if
-    (titel && bibinf_hit_header
-     && (!bibinf_separator_function(line))
-     && (strchr(line, ':') != NULL)){
-      titel = false;
-      bibinf_hit_header = false; 
-    }
-  else if (titel){
-    titel = false;
-    bibinf_hit_header = false;     
-  }
-}
-
-void bibinf_finish_header_function(header)
-char *header;
-
-{
-  bibinf_hit_header = true; /* turn on the flag */
-  if (strlen(bibinf_header) == 0) {
-    strcpy(header, "No Title");
-  }
-  else {
-    strncpy(header, bibinf_header, MAX_HEADER_LEN);
-/*    s_strncpy(header, bibinf_header,60);
-    if(header[strlen(header)-1] != '\n')
-      strcat(header,"...\n"); */
-  }
-  bibinf_header[0] = '\0';
-}
-
-
-#endif /* SIMPLE_BIBINF */
-
-long binfgetdate(s)
-     char *s;
-{
-  int year, month, day;
-
-  sscanf(s, "%4d-%2d-%2d", &year, &month, &day);
-  return (10000 * (year - 1900) + 100 * month + day);
-}
-
-long bibinf_date_function(line)
-char *line;
-{
-  if((strlen(line) > strlen("Erfasst: ")) &&
-     substrcmp(line, "Erfasst: ")){
-    return(binfgetdate(line+9));
-  }
-  else return -1;
-}
-  
-
-/* ========================================
- * ===  Irlist Digest Customizations     ====
- * ========================================
- */
-
-boolean irlist_separator_function(line)
-char *line;
-{
-  if (mail_or_rmail_separator(line)) return(true);
-  
-  if((strlen(line) > strlen("*********")) &&
-     substrcmp(line, "**********")){
-    return(true);
-  }
-  else{
-    return(false);
-  }
-}
-
-void irlist_header_function(line)
-char *line;
-{
-  if((strlen(line) > strlen("Re: ")) &&
-     substrcmp(line, "Re: ") &&
-     (strlen(mail_subject) == 0)){
-    strcpy(mail_subject, "Re: ");
-    s_strncat(mail_subject, line + strlen("Re: "), MAX_HEADER_LEN, MAX_HEADER_LEN);
-    trim_trailing_newline(mail_subject);
-  }
-  else if((strlen(line) > strlen("Fr: ")) &&
-     substrcmp(line, "Fr: ") &&
-     (strlen(mail_from) == 0)){
-    /* this should find the <foo@bar> field in the from list */
-    strncpy(mail_from, line + strlen("Fr: "), MAX_HEADER_LEN);
-    trim_trailing_newline(mail_from);
-  }
-  else mail_header_function(line);
-}
-
-long irlist_date_function(line)
-char *line;
-{
-  static long last_date = 0;
-  long this_date;
-  
-  if ((this_date = mail_date_function(line)) > 0)
-    return(last_date = this_date);
-  else
-    return(last_date);
-}
-
-#endif
-
 #ifdef STELAR
 
 /*=================================
@@ -3520,14 +3012,13 @@ void stelar_finish_header_function(header)
   }
   stelar_header[0]='\0';
 }
-#endif /* STELAR */
+
 /*=================================
  *
  *      AAS Meeting Abstracts
  *      (using AAS abstract LaTeX macros)
  *
  *=================================*/
-#ifdef AAS
 
 #define AASAB_TITLE_MARKER "\\title{"
 #define AASAB_AUTHOR_MARKER "\\author{"
@@ -3590,7 +3081,7 @@ void aasab_finish_header_function(line)
   aasab_title[0] = '\0';
 }
 
-#endif /* AAS */
+#endif /* STELAR */
 
 
 char *URL_prefix=NULL;
