@@ -10,13 +10,6 @@
 
 /* Change log:
  * $Log: irinv.c,v $
- * Revision 1.3  1993/09/23  03:00:07  pfeifer
- * undid swap.
- * Fixed bug with string compare (strcmp) for ISO-Chars
- *
- * Revision 1.2  1993/09/23  02:12:20  pfeifer
- * swaped from_version and into_version merge_index_file
- *
  * Revision 1.1  1993/02/16  15:05:35  freewais
  * Initial revision
  *
@@ -31,13 +24,6 @@
  * 
  * Revision 1.25  92/02/12  13:27:31  jonathan
  * Added "$Log: irinv.c,v $
- * Revision 1.3  1993/09/23  03:00:07  pfeifer
- * undid swap.
- * Fixed bug with string compare (strcmp) for ISO-Chars
- *
- * Revision 1.2  1993/09/23  02:12:20  pfeifer
- * swaped from_version and into_version merge_index_file
- *
  * Revision 1.1  1993/02/16  15:05:35  freewais
  * Initial revision
  *
@@ -521,7 +507,6 @@ static boolean merge_index_file _AP((long from_version, long into_version,
 
 /* Merges a index file (from_version) into another (into_version).
    Returns true if successful */
-
 static boolean merge_index_file(into_version, from_version, 
 				db,generate_dictionary)
 long into_version;
@@ -617,10 +602,7 @@ boolean generate_dictionary;
       long strlen_1 = strlen(input_word_1);
       long strlen_2 = strlen(input_word_2);
       long compare = strcmp(input_word_1, input_word_2); /* +1 if 1 is bigger */
-      if (!strlen_1) {          /* Make it work for iso chars */
-        if (!strlen_2) compare = 0;
-        else           compare = -1;
-      }
+
       if((0 == strlen_1) && 
 	 (0 == strlen_2)){
 	/* printf("Done with merge\n"); */
