@@ -18,11 +18,7 @@
  */
  
 /* Change Log:
- * $Log: irsearch.c,v $
- * Revision 1.5  1993/10/17  15:38:50  huynh1
- * new code added for soundex, phonix retrieval and
- * nested boolean queries.
- *
+ * $Log:	irsearch.c,v $
  * Revision 1.3  93/07/21  18:46:35  warnock
  * Added STELAR-specific patches
  * 
@@ -126,16 +122,6 @@
 #ifdef BOOL
 #include "irparse.h"
 #endif
-#ifdef SOUND
-#include "soundex.h"
-#endif
-
-/* tung , 10/93 */
-#ifdef BOOLEANS
-#include "manipulstr.h"
-#endif
-/* tung */
-
 #include "trie.h"
 
 #define TEST_SEARCH 	false	/* set to TRUE to allow printing to console */
@@ -356,13 +342,12 @@ boolean result;
 /* dgg -- pulled this from irtfiles.c:map_over_words */
 /* returns the number of words added, or -1 if an error occurred */
 long search_over_words
-  _AP((char* line,long document_id,database* db,char* words_used));
+  _AP((char* line,long document_id,database* db));
        
-long search_over_words(line, document_id, db, words_used) 
+long search_over_words(line, document_id, db) 
 char* line;
 long document_id;
 database* db;
-char* words_used;
 {
   long weight = 1L;
   long file_position_before_line = 0;
@@ -389,29 +374,13 @@ char* words_used;
 #define MAX_LINE_LENGTH 1000  
   boolean  nextIsNot = false;
   char  notwords[MAX_LINE_LENGTH+1];
-  boolean parentheses = false; /* 10/93, tung */
-#endif
-#ifdef SOUND
-  boolean nextIsSoundex = false;
-  boolean nextIsPhonix = false;
 #endif
 
+
 #ifdef BOOLEANS
   notwords[0]= '\0';
-
-/* tung, 10/93 
-     for boolean search with parentheses "(... and ... )".
-     There may but need not be blanks (or tabs) around the parentheses.
-     */
-  if((strchr(line, '(' )) && (strchr(line, ')' ))) {
-    parentheses = true;
-    line = string_manipulation(line);
-    minwordlen = 1; /* e.g. for query (a or information) */
-  }
-/* tung, 10/93 */
 #endif
 
-
   for(ch = (unsigned char)line[char_count++]; 
       ch != '\0'; ch = (unsigned char)line[char_count++]){
 #ifdef BIO
@@ -425,9 +394,7 @@ char* words_used;
 #ifdef LITERAL
    if (ch == LITERAL_KEY1)  key= LITERAL_KEY1;
    else if (ch == LITERAL_KEY2)  key= LITERAL_KEY2;
-   else { key= 0; weight = 1L ;} /* by only key=0 is it not possible
-                                    combine literal search and boolean search
-                                  */
+   else key= 0;
    if (key != 0) {
       char *cp, *match;
       cp = line + char_count;  
@@ -446,7 +413,7 @@ char* words_used;
 	/* !! need to break literal "word" into 1st dictionary word and search
 		on that... */
 /* printf("search_over_words: literal is [%s]\n", word); */
-        }
+	  }
       }
 #endif
 
@@ -473,81 +440,15 @@ char* words_used;
  	  word_count++;
 	  }
 	else if ((strncmp(word,BOOLEAN_NOT,position_in_word)==0)) {
-          if(parentheses == false) {  /* tung, 10/93 */
-            nextIsNot= true;
-            word_count++;
-          }
-          else {                      /* tung, 10/93 */
-            word[position_in_word] = '\0';
-            if(0 != search_word_before_pairs
-               (word,
-                file_position_before_line + char_count,  
-                /*^^  this param is supposed to be start-of-word, but char_count is now at end-of-word !*/
-                0L, /* line_pos */
-                weight, 
-                document_id, 
-                (time_t)0L,
-                capitalized,
-                db))  
-              return(-1); /* error */
-            nextIsNot= false;
-            word_count++;
-          }
-        }
-	else
-#endif
-#ifdef SOUND
-          if (nextIsSoundex) {
-            static char Key[80];
-            word[position_in_word] = '\0';
-            SoundexCode(word,Key);
-#ifdef DEBUG
-            printf("search_over_words: adding Soundex (%s,%s)\n", word, Key);
-#endif
-            if(0 != search_word_before_pairs
-               (Key,
-                file_position_before_line + char_count, 
-                0L,	/* line_pos */
-                weight, 
-                document_id, 
-                (time_t)0L,
-                capitalized,
-                db))
-              return(-1);
-            word_count++; nextIsSoundex = false;
-          } else if ((strncmp(word,SOUNDEX,strlen(SOUNDEX))==0)) {
-            nextIsSoundex= true;
-            word_count++;
+	  nextIsNot= true;
+ 	  word_count++;
 	  }
-          else if (nextIsPhonix) {
-            char Key[80];
-            word[position_in_word] = '\0';
-            PhonixCode(word,Key);
-#ifdef DEBUG
-            printf("search_over_words: adding Phonix (%s,%s)\n", word, Key);
-#endif
-            if(0 != search_word_before_pairs
-               (Key,
-                file_position_before_line + char_count, 
-                0L,	/* line_pos */
-                weight, 
-                document_id, 
-                (time_t)0L,
-                capitalized,
-                db))
-              return(-1);
-            word_count++; nextIsPhonix = false;
-          } else if ((strncmp(word,PHONIX,strlen(PHONIX))==0)) {
-            nextIsPhonix= true;
-            word_count++;
-          } else
+	else
 #endif
 	/* then we have collected a word */
 	if(position_in_word >= minwordlen){ /* is it reasonable ? */
-	  long result;
 	  word[position_in_word] = '\0';
-	  if(0 > (result = 
-		  search_word_before_pairs(word,
+	  if(0 != search_word_before_pairs(word,
 			     file_position_before_line + char_count,  
 			     /*^^  this param is supposed to be start-of-word, but char_count is now at end-of-word !*/
 			     0L, /* line_pos */
@@ -555,18 +456,10 @@ char* words_used;
 			     document_id, 
 			     (time_t)0L,
 			     capitalized,
-			     db)))
+			     db))  
 	    return(-1); /* error */
-	    if(result == 1 && words_used != NULL) {
-	    strcat(words_used, word);
-	    strcat(words_used, " ");
-	  }
 #ifdef BOOLEANS
 	  nextIsNot= false;
-#endif
-#ifdef SOUND
-              nextIsPhonix = false;
-              nextIsSoundex = false;
 #endif
  	  word_count++;
 	}
@@ -576,7 +469,6 @@ char* words_used;
   }
   
   /* finish last word */
-
 #ifdef BOOLEANS
   if (nextIsNot) {
     word[position_in_word] = '\0';
@@ -586,57 +478,10 @@ char* words_used;
     word_count++;
     }
  else 
-#endif
-#ifdef SOUND
-    if (nextIsSoundex) {
-    static char Key[80];
-    long result;
-    word[position_in_word] = '\0';
-    SoundexCode(word,Key);
-#ifdef DEBUG
-    printf("search_over_words: adding Soundex (%s,%s)\n", word, Key);
-#endif
-    if(0 > (result = 
-	    search_word_before_pairs(Key,
-                                     file_position_before_line + char_count, 
-                                     0L,	/* line_pos */
-                                     weight, 
-                                     document_id, 
-                                     (time_t)0L,
-                                     capitalized,
-                                     db)))
-      return(-1);
-    word_count++;
-    }
-    else if (nextIsPhonix) {
-      char Key[80];
-      long result;
-      word[position_in_word] = '\0';
-      PhonixCode(word,Key);
-#ifdef DEBUG
-      printf("search_over_words: adding Phonix (%s,%s)\n", word, Key);
-#endif
-      if(0 > (result = 
-	      search_word_before_pairs(Key,
-                                       file_position_before_line + char_count, 
-                                       0L,	/* line_pos */
-                                       weight, 
-                                       document_id, 
-                                       (time_t)0L,
-                                       capitalized,
-                                       db)))
-      return(-1);
-      if (result == 1 && words_used != NULL) {
-	strcat(words_used, word);
-	strcat(words_used, " ");
-      }
-      word_count++;
-    }
-  else
 #endif
  if(position_in_word >= minwordlen){ /* is it reasonable ? */
     word[position_in_word] = '\0';
-    if(0 > search_word_before_pairs(word,
+    if(0 != search_word_before_pairs(word,
 			    file_position_before_line + char_count, 
 			    0L,	/* line_pos */
 			    weight, 
@@ -650,33 +495,31 @@ char* words_used;
   
 #ifdef BOOLEANS
   if ((notwords[0] != '\0')) { 
-    char wordn[MAX_WORD_LENGTH+1];   /* this is a copy of wordp */
     char  *wordp;
     capitalized= false;
     char_count= 0;       /* !?? need char index for each word ? */
     weight= BOOLEAN_NOT_FLAG; /* is this a safe parameter ? */   
     wordp= strtok( notwords, " ");
     while (wordp!=NULL) {
-      s_strncpy(wordn,wordp,MAX_WORD_LENGTH);
-      if(0 > 
-	 search_word_before_pairs(wordn,
-                                       file_position_before_line + char_count, 
-                                       0L,	/* line_pos */
-                                       weight, 
-                                       document_id, 
-                                       (time_t)0L,
-                                       capitalized,
-                                       db))  
+      if(0 != search_word_before_pairs(wordp,
+			    file_position_before_line + char_count, 
+			    0L,	/* line_pos */
+			    weight, 
+			    document_id, 
+			    (time_t)0L,
+			    capitalized,
+			    db))  
         return(-1);
-      wordp= strtok(NULL, " ");
+      wordp= strtok(NULL," ");
+      }
     }
-  }
 #endif
+
   return(word_count);
 }
 
 
-boolean search_for_words(words, db, doc_id, words_used)
+boolean search_for_words(words, db, doc_id)
      char* words;
      /* break the string into words (using map_over_words)
 	and repeatedly call search_word_before_pairs(). 
@@ -684,7 +527,6 @@ boolean search_for_words(words, db, doc_id, words_used)
 	*/
      database *db;
      long doc_id;  /* = 1 for words == document in relevance feedback search */
-     char   *words_used;
 {
 
 #ifdef BOOL
@@ -710,7 +552,7 @@ boolean search_for_words(words, db, doc_id, words_used)
 */
 
   /* NORMAL QUERY */
-  if( -1 == search_over_words(words, doc_id, db, words_used))
+  if( -1 == search_over_words(words, doc_id, db))
     return(false);
   else
     return(true); 
@@ -726,48 +568,48 @@ long next_best_hit(the_best_hit, db)
 {
   document_table_entry doc_entry;
   long ret_value,start,end,length,date,nlines=0;
-  char headline[100];
-  char filename[200],type[20];
+char headline[100];
+char filename[200],type[20];
   while(1){ /* keep going until we get a good document */
     if(0 != (ret_value = best_hit(db,&(the_best_hit->document_id),
 				  &(the_best_hit->best_character),
 				  &(the_best_hit->best_line),
 				  &(the_best_hit->weight),
 				  &start,&end,&date,&length,&nlines,
-                                  headline,filename,type))){
-      /* if we add start,end,length,date,headline here, we can remove lots of
-         disk reads */
-      
+				headline,filename,type))){
+/* if we add start,end,length,date,headline here, we can remove lots of
+disk reads */
+
       return(ret_value);
-    }
+}
     if(the_best_hit->weight <= 0.0)	/* if we are out of good stuff, return */
       return(1);
-    /* fill in the rest of the hit [uwo] do this with a read...
-    the_best_hit->start_character = start;
-    the_best_hit->end_character = end;
-    the_best_hit->document_length = length;
-    the_best_hit->number_of_lines = nlines;    [uwo] handle these below */
-    strcpy(the_best_hit->filename,filename);
-    strcpy(the_best_hit->type,type);
-    strcpy(the_best_hit->headline,headline);
-/*      sprintf(the_best_hit->date, "%d", date); [uwo] handled below */
-/* do we need this step??  JMF -- It would seem so. Peter Marshall [uwo]. */
-    if (read_document_table_entry(&doc_entry, the_best_hit->document_id, db)){
-         the_best_hit->start_character = doc_entry.start_character;
-         the_best_hit->end_character = doc_entry.end_character;
-         the_best_hit->document_length = doc_entry.document_length;
-         the_best_hit->number_of_lines = doc_entry.number_of_lines;
-         sprintf(the_best_hit->date, "%d", doc_entry.date);
-/*   This doesn't seem to be necessary, though -- Peter Marshall [uwo]
-         read_filename_table_entry(doc_entry.filename_id, 
-         the_best_hit->filename,
-         the_best_hit->type,
-         NULL,
-         db),
-         strncpy(the_best_hit->headline, 
-         read_headline_table_entry(doc_entry.headline_id,db),
-         MAX_HEADLINE_LEN);
-[uwo] */
+    /* fill in the rest of the hit */
+      the_best_hit->start_character = start;
+      the_best_hit->end_character = end;
+      the_best_hit->document_length = length;
+      the_best_hit->number_of_lines = nlines;
+	strcpy(the_best_hit->filename,filename);
+	strcpy(the_best_hit->type,type);
+	strcpy(the_best_hit->headline,headline);
+      sprintf(the_best_hit->date, "%d", date);
+/* do we need this step??  JMF */
+    if (/*read_document_table_entry(&doc_entry, the_best_hit->document_id, db)*/true == true){
+/*
+      the_best_hit->start_character = doc_entry.start_character;
+      the_best_hit->end_character = doc_entry.end_character;
+      the_best_hit->document_length = doc_entry.document_length;
+      the_best_hit->number_of_lines = doc_entry.number_of_lines;
+      sprintf(the_best_hit->date, "%d", doc_entry.date);
+      read_filename_table_entry(doc_entry.filename_id, 
+				the_best_hit->filename,
+				the_best_hit->type,
+				NULL,
+				db),
+      strncpy(the_best_hit->headline, 
+	      read_headline_table_entry(doc_entry.headline_id,db),
+	      MAX_HEADLINE_LEN);
+*/
       if(probe_file_possibly_compressed(the_best_hit->filename))
 	return(0);
       else {
@@ -826,6 +668,7 @@ char* server;
       else if(strcmp(docs[0]->Type,"WAIS_PREV") == 0)		/* prev page */
 	id = previous_docid(local_id, db);
 
+
       freeDocID(theDocID); s_free(local_id);
 
       if (id > -1) {
@@ -1037,34 +880,6 @@ long *num_diags;
 
 
 /*----------------------------------------------------------------------*/
-#ifdef FIXDATE
-FixDate(date)
-char *date;
-{
-  long ndate;
-  int year, month, day;
-  ndate = atoi(date);
-  year  = ndate/10000;
-  month = (ndate-10000*year)/100;
-  day   = (ndate-10000*year-100*month);
-#ifdef DEBUG
-  fprintf(stderr, "FixDate: %ld (%d/%d/%d)\n", ndate, year, month, day);
-  fprintf(stderr, "FixDate: %s\n", date);
-#endif
-  if (year>100) strcpy(date,"0");
-  else if (month>12) strcpy(date,"0");
-  else if (day>31)   strcpy(date,"0");
-}
-#endif 
-
-#ifdef ONELINELENGTH
-FixLength(length)
-int *length;
-{
-  if (*length<MAX_HEADLINE_LEN)
-    *length=0;
-}
-#endif
 
 WAISDocumentHeader*
 best_hit_to_header(best_hit, maxRawScore, waisProtocolVersion, server, db)
@@ -1213,12 +1028,7 @@ database* db;
 		  
       theDocID->distributorLocalID = stringToAny(local_id);
       theDocID->originalLocalID = stringToAny(local_id);
-#ifdef FIXDATE
-      FixDate(best_hit->date);
-#endif
-#ifdef ONELINELENGTH
-      FixLength(&length);
-#endif
+
       header =
 	makeWAISDocumentHeader(anyFromDocID(theDocID),
 			       UNUSED,
@@ -1332,9 +1142,7 @@ long *headerNum;
   }
   
   /* until seed_words_used is supported */
-/*  strcpy(*seed_words_used, wais_search->SeedWords); */
-
-  if (seed_words_used != NULL) *seed_words_used[0] = 0;
+  strcpy(*seed_words_used, wais_search->SeedWords);
 
   parameters.max_hit_retrieved = wais_search->MaxDocumentsRetrieved;
   set_query_parameter(SET_MAX_RETRIEVED_MASK, &parameters);
@@ -1361,7 +1169,7 @@ long *headerNum;
   }
 #endif				/* RELEVANT_FEEDBACK */
 
-  search_result |= search_for_words(wais_search->SeedWords, db, 0, *seed_words_used);
+  search_result |= search_for_words(wais_search->SeedWords, db, 0);
 
   if (search_result == true){ /* the search went ok */
       hit best_hit;
