@@ -10,24 +10,14 @@
 
 /* Change log:
  * $Log:	irtfiles.c,v $
- *
- * Revision 1.4a  93/07/23  02:19:27  warnock
+ * Revision 1.4  93/07/23  02:19:27  warnock
  * corrected arguments in call to map_over_words in finish_document
- *
- * Revision 1.4  1993/09/22  16:07:52  pfeifer
- * Fixed word breaking for german ISO Umlaute and sz
  * 
- * Revision 1.3a  93/07/19  17:06:03  warnock
+ * Revision 1.3  93/07/19  17:06:03  warnock
  * fixed problem with multiple documents in single file, from isaacs@hpcc05.corp.hp.com
- *
- * Revision 1.3  1993/06/04  10:23:15  pfeifer
- * Pachtlevel BIBDB
  * 
- * Revision 1.2a  93/07/19  16:31:27  warnock
+ * Revision 1.2  93/07/19  16:31:27  warnock
  * Added document type URL from Nathan.Torkington@vuw.ac.nz
- *
- * Revision 1.2  1993/06/01  14:05:54  pfeifer
- * Added code for soundex/phonix indexing and retrieval
  * 
  * Revision 1.1  1993/02/16  15:05:35  freewais
  * Initial revision
@@ -86,10 +76,6 @@
 #include "ircfiles.h"   /* dgg, need for genbank_header_function test */
 #include "stemmer.h"   
 
-#ifdef SOUND
-#include "soundex.h"
-#endif
-
 #ifndef THINK_C
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -123,7 +109,6 @@ boolean index_contents = true;
 #define keyword_weight 1
 
 /* keywords from command line (set in waisindex.c), used in finish_document */
-
 char* keywords = NULL;
 
 /* name of keyword file from command line, used in finish_document */
@@ -304,12 +289,7 @@ long map_over_words(line,
 		    db,
 		    wordfunction,
 		    word_position, word_pairs,
-#ifdef SOUND
-		    minwordlen, type)	
-#else
 		    minwordlen)	/* dgg */
-#endif
-
 char* line;
 long document_id;
 long weight;
@@ -320,10 +300,6 @@ database* db;
 wordfunc *wordfunction;
 boolean word_position, word_pairs;
 int	minwordlen;
-#ifdef SOUND
-char* type;
-#endif
-
 {
   /* Add words to the index if it should be done. 
    * Returns the number of words added.
@@ -347,7 +323,7 @@ char* type;
 #ifdef BIO
     boolean alnum = (wordDelimiter(ch) == NOT_DELIMITER);
 #else
-    boolean alnum = isalnum(ch) || wordbreak_isiso(ch);
+    boolean alnum = isalnum(ch);
 #endif
 
     if(alnum){
@@ -382,41 +358,6 @@ stemmer(word);
 	    return(-1); /* error */
  	  word_count++;
 	}
-
-#ifdef SOUND
-          /*=========================== SOUNDEX / PHONIX ========================================*/
-        if ((word_count == 1) && (type != NULL)) /* use only the first word (i.e. the surname) for SOUNDEX/PHONIX! */
-          if ((!strcmp(type, "SOUNDEX")) || (!strcmp(type, "PHONIX"))) 
-            {
-              char code[20];
-              int  i;
-             
-              if (!strcmp(type, "SOUNDEX"))
-                Soundex(word, code);
-              else if (!strcmp(type, "PHONIX"))
-                Phonix(word, code);
-            
-              code[0] = tolower(code[0]);
-#ifdef DEBUG
-              fprintf(stderr, "%5d, %4s, %s\n", word_count, code, word); 
-#endif
-              if (0 != (*wordfunction) (code,
-                                        file_position_before_line + char_count, 
-                                        0L, /* line_pos */
-                                        weight, 
-                                        document_id, 
-                                        (time_t) 0L,
-                                        capitalized,
-                                        db,
-                                        word_position,
-                                        word_pairs))
-                return(-1);       /* error */
-              
-              word_count++;
-            }
-          /*=====================================================================================*/
-#endif
-
 	position_in_word = 0;
       }
     }
@@ -592,32 +533,18 @@ unsigned long *i, *j;
 #define iterations_to_reorder 50 /* 1 is best but slow */
 
 static void finish_document
-#ifndef SOUND 
   _AP((boolean recountHeader, char* header,char* line,long document_id,
        document_table_entry* the_document_table_entry,
        long file_position_before_line,
        long file_position_before_document,database* db,
        boolean word_position, boolean word_pairs,
        int minwordlen));
-#else
-  _AP((boolean recountHeader, char* header,char* line,long document_id,
-       document_table_entry* the_document_table_entry,
-       long file_position_before_line,
-       long file_position_before_document,database* db,
-       boolean word_position, boolean word_pairs,
-       int minwordlen, 
-       char* type));
-#endif
 
 static void
 finish_document(recountHeader, header,line,document_id,the_document_table_entry,
 		file_position_before_line, file_position_before_document,
 		db, word_position, word_pairs,
-#ifndef SOUND
 		minwordlen)
-#else
-                minwordlen, type)
-#endif
 boolean recountHeader;
 char* header;
 char* line;
@@ -627,9 +554,6 @@ long file_position_before_line;
 long file_position_before_document;
 database* db;
 boolean word_position, word_pairs;
-#ifdef SOUND
-char* type;
-#endif
 { long line_length;
   boolean newline_terminated;
   long number_of_words;
@@ -647,12 +571,7 @@ char* type;
 		     db,
 		     add_word_before_pairs,
 		     word_position, word_pairs,
-#ifdef SOUND
-		     minwordlen, type);
-#else
 		     minwordlen);
-#endif
-
     if(number_of_words == -1)
       waislog(WLOG_HIGH, WLOG_ERROR, "map_over_words failed");
     db->total_word_count += number_of_words;
@@ -702,11 +621,7 @@ char* type;
  			 &newline_terminated,
  			 db,
  			 add_word_before_pairs,
-#ifdef SOUND
- 			 word_position, word_pairs, minwordlen, type);
-#else
  			 word_position, word_pairs,minwordlen);
-#endif /* SOUND */
  	if(number_of_words == -1)
  	  waislog(WLOG_HIGH, WLOG_ERROR, "map_over_words failed");
  	db->total_word_count += number_of_words;
@@ -840,8 +755,7 @@ printf(", max: %lu/%lu\n",nodes[(nodeRange * 2)-2],nodes[(nodeRange * 2)-1]);
 void index_text_file(filename, dataops, db,
 		     check_for_text_file,
 		     check_for_file_already_indexed,
-		     word_position, word_pairs,
-		     filter_process_in, filter_process_out)	 
+		     word_position, word_pairs)	 
 char* filename;
 dataopsrec* dataops;
 /*
@@ -855,12 +769,8 @@ database* db;
 boolean check_for_text_file;
 boolean check_for_file_already_indexed;
 boolean word_position, word_pairs;
-FILE *filter_process_in, *filter_process_out;
 {
-  /* Adds words to the index for a given file.  
-   * "words" are extracted as strings of alphanumeric chars, whose
-   *  length is >=3 but <toobig.  Long lines are handled in chunks
-   *  so that binary files with embedded text are correctly processed.
+  /* Addes words to the index for a given file.  
    * The function arguments can be NULL which means it would 
    *  always answer NULL.  
    * separator_function is called on every line to see if it 
@@ -894,8 +804,8 @@ FILE *filter_process_in, *filter_process_out;
   long file_position_before_line = 0;
   long file_position_before_document = 0;
   long date;
-  int  charsleftover;
-  char leftovers[MAX_LINE_LENGTH];
+
+  
  
    if(filename != NULL &&
       strlen(filename) > 1 &&
@@ -1006,7 +916,6 @@ FILE *filter_process_in, *filter_process_out;
   the_document_table_entry.document_length = 0;
   the_document_table_entry.number_of_lines = 0;
   the_document_table_entry.date = 0;
-  charsleftover = 0;
 
   while(TRUE){
     long line_length;
@@ -1016,45 +925,15 @@ FILE *filter_process_in, *filter_process_out;
     char* read_line_result;
     boolean eof;
 
-    int i, cut, charsread;
-
-    /*  
-     *  Read a block of up to MAX_LINE_LENGTH chars from a single "line"
-     *	and extract a whole number of words from it.  Save partial words
-     *	lying at edge of block in the leftovers[] array for the next loop.
-     *	This accomodates binary files formats with embedded text, which
-     *	often have very long "lines".   [burchard@geom.umn.edu 4/16/93]
-     */
-
-    /* prefill line with leftovers before reading in new data */
+    /* printf("ftell: %ld\n", ftell(input_stream)); */
+    /* read a line */
+    read_line_result  = fgets(line, MAX_LINE_LENGTH, input_stream);
     beFriendly();
-
-    for(i=0; i<charsleftover; i++) line[i] = leftovers[i];
-    line[charsleftover] = '\0';
-    read_line_result = fgets(line + charsleftover,
-      MAX_LINE_LENGTH - charsleftover, input_stream);
-
-    /* increment line count if we have finished reading a "line" */
-    charsread = strlen(line);
-    if(charsread>charsleftover && line[charsread-1]=='\n')
-
-      the_document_table_entry.number_of_lines++;
-
-    /* save word frag at end as leftovers (unless it fills whole block) */
-    for(cut=charsread-1; cut>=0; cut--)
-      if(!isascii(line[cut]) || !isalnum(line[cut])) break;
-    if(++cut <= 0) charsleftover = 0;
-    else {
-      for(charsleftover=0, i=cut; i<charsread; charsleftover++, i++) 
-
-        leftovers[charsleftover] = line[i];
-      charsread -= charsleftover;
-    }
-    line[charsread] = '\0';
-
-    /* don't say EOF yet if we still have leftovers to process */
-    eof = (!read_line_result && !charsread && !charsleftover);
-
+ 	
+    /* eof = feof(input_stream); */ /* zero means not eof */
+    eof	= !read_line_result; 
+    
+    the_document_table_entry.number_of_lines++;
 
     header[0] = '\0';		/* set it to the empty string */
 
@@ -1087,8 +966,7 @@ FILE *filter_process_in, *filter_process_out;
 	} else
           strncpy(header, current_filename, MAX_FILENAME_LEN);
       }
-      if(the_document_table_entry.number_of_lines > 0)
-        the_document_table_entry.number_of_lines--; /* dont count separator */
+      the_document_table_entry.number_of_lines--; /* dont count separator */
       /* finish off the last */
       finish_document( dataops->extraheaderweight,
 		      header, line, document_id,
@@ -1097,11 +975,7 @@ FILE *filter_process_in, *filter_process_out;
 		      file_length(input_stream):file_position_before_line, 
 		      file_position_before_document,
 		      db, word_position, word_pairs,
-#ifndef SOUND
 		      dataops->minwordlen);
-#else
-		      dataops->minwordlen, dataops->indextype);
-#endif
       /* initialize the next one */
       the_document_table_entry.filename_id = filename_id;
       the_document_table_entry.start_character = file_position_before_line;
@@ -1132,12 +1006,7 @@ FILE *filter_process_in, *filter_process_out;
                                          db,
                                          add_word_before_pairs,
                                          word_position, word_pairs,
-#ifdef SOUND
-                                         dataops->minwordlen,
-                                         dataops->indextype);
-#else
 					 dataops->minwordlen);
-#endif /* SOUND */
           the_document_table_entry.document_length += number_of_words;
           len_of_files_since_last_delete += number_of_words;
           len_of_files_since_last_flush += number_of_words;
@@ -1174,12 +1043,7 @@ FILE *filter_process_in, *filter_process_out;
 					 db,	
 					 add_word_before_pairs,
 					 word_position, word_pairs,
-#ifdef SOUND
-					 dataops->minwordlen,
-                                         dataops->indextype);
-#else
 					 dataops->minwordlen);
-#endif
 	  if(number_of_words == -1)
 	    waislog(WLOG_HIGH, WLOG_ERROR, "map_over_words failed");
 	  the_document_table_entry.document_length += number_of_words;
@@ -1253,15 +1117,13 @@ char *file;
 void index_directory(file, dataops,  db,
 		     check_for_text_file,
 		     check_for_file_already_indexed,
-		     word_position, word_pairs,
-		     filter_process_in, filter_process_out)
+		     word_position, word_pairs)
 char *file;
 dataopsrec*  dataops;
 database* db;
 boolean check_for_text_file;
 boolean check_for_file_already_indexed;
 boolean word_position, word_pairs;
-FILE *filter_process_in, *filter_process_out;
 {
 #ifndef THINK_C
   struct dirent **list;
@@ -1273,7 +1135,7 @@ FILE *filter_process_in, *filter_process_out;
     index_text_file(file, dataops, db,
 		    check_for_text_file,
 		    check_for_file_already_indexed,
-		    word_position, word_pairs,NULL,NULL);
+		    word_position, word_pairs);
   }
   else if(directoryp(file)){
     if ((i = scandir(file, &list, NULL, NULL)) < 0) {
@@ -1293,7 +1155,7 @@ FILE *filter_process_in, *filter_process_out;
       index_directory(name, dataops, db,
 		      check_for_text_file,
 		      check_for_file_already_indexed, 
-		      word_position, word_pairs,NULL,NULL);
+		      word_position, word_pairs);
     }
     if(list != NULL) {
       for (j = 0; j < i; j++)
