@@ -6,6 +6,8 @@
 
 /* Copyright (c) CNIDR (see ../COPYRIGHT) */
 
+
+
 /* implements the search part of irext.h 
    (search_word and finished_search_word)
    -brewster
@@ -19,22 +21,15 @@ Split from irsearch.c
    - Jonny G
  * $Log:	sersrch.c,v $
  * Revision 1.33  93/07/21  18:47:38  warnock
- * Added STELAR-specific patches
- *
- * Revision 1.10  1993/10/13  14:14:20  huynh1
- * new code added for encapsulated boolean queries and
- * modified literal search
+ * Added STELAR-secific patches
  * 
  * Revision 1.32  93/07/19  17:09:39  warnock
  * fixed problem with multiple documents in single file, from isaacs@hpcc05.corp.hp.com
- *
- * Revision 1.3  1993/07/13  08:19:56  pfeifer
- * Sicherung vor Aenderungen Tung
  * 
  * Revision 1.31  93/07/02  18:31:06  warnock
  * included ctype.h
  * 
- * Revision 1.3a  93/07/02  17:59:25  warnock
+ * Revision 1.3  93/07/02  17:59:25  warnock
  * change to search_word to handle compressed files from francois
  * 
  * Revision 1.1  1993/02/16  15:05:35  freewais
@@ -61,7 +56,7 @@ Split from irsearch.c
 #include "irfiles.h"
 #ifdef BIO
 #include "irtfiles.h" /* dgg, for wordDelimiter */
-#endif /* BIO */
+#endif
 #include "irsearch.h"
 #include "irext.h"
 #include "byte_order.h"
@@ -70,24 +65,10 @@ Split from irsearch.c
 
 #include <math.h>
 
-/* tung, 10/93 */
-#ifdef BOOLEANS
-#include "boolean_op.h"
-#endif /* BOOLEANS */
-/* tung, 10/93 */
-
-/* #define MAXINT (unsigned long)2^(sizeof(long)*8-1) */
-
+#define MAXINT (unsigned long)2^(sizeof(long)*8-1)
 #define VALUE 1000000L
-
 #include "stemmer.h"   
 
-/* tung, 10/93 */
-#ifdef BOOLEANS
-#include "boolean_op.h"
-#endif /* BOOLEANS */
-/* tung, 10/93 */
-
 #ifdef BOOL
 #include "obj.h"
 #include "irparse.h"
@@ -121,7 +102,7 @@ text_size, grow_percent)
 #ifdef BOOL
      initObj();
      initBool();
-#endif /* BOOL */
+#endif
      inited = true;
    }
 
@@ -219,12 +200,7 @@ double *document_score_array = NULL;
 long document_score_array_len = 0;
 #ifdef BOOLEANS
 double *prev_score_array = NULL;					/* 12/91 GS TLG */
-
-/* tung, 10/93 */
-search_result_struct *search_result_array = NULL;
-/* tung, 10/93 */
-
-#endif /* BOOLEANS */
+#endif
 
 /* make_document_score_array insures that the document_score_array
    array is long enough, if not it makes it long enough */
@@ -239,13 +215,13 @@ long length;
     s_free(document_score_array);
 #ifdef BOOLEANS
     s_free(prev_score_array);					/* 12/91 GS TLG */
-#endif /* BOOLEANS */
+#endif
   }
   document_score_array = (double*)s_malloc(
 					 (size_t)(length * sizeof(double)));
 #ifdef BOOLEANS
   prev_score_array   = (double*)s_malloc((size_t)(length * sizeof(double)));  /* 12/91 GS TLG */
-#endif /* BOOLEANS */
+#endif
   document_score_array_len = length;
 }
 
@@ -255,7 +231,7 @@ static void destroy_document_score_array()
   s_free(document_score_array);
 #ifdef BOOLEANS
   s_free(prev_score_array);					/* 12/91 GS TLG */
-#endif /* BOOLEANS */
+#endif
   document_score_array_len = 0;
 }
     
@@ -267,7 +243,7 @@ void clear_document_score_array()
 #ifdef BOOLEANS
   memset(prev_score_array, 0,					/* 12/91 GS TLG */
          document_score_array_len * sizeof(double));		/* 12/91 GS TLG */
-#endif /* BOOLEANS */
+#endif
 }
 
 /* for debugging purposes */
@@ -370,12 +346,11 @@ void sort_best_hits(db)
   }
 
   /* loop over the doc, and keep the doc_id and weight in best hit table */
-  for(doc = 1; doc < db->doc_table_allocated_entries; doc++){
+  for(doc = 0; doc < db->doc_table_allocated_entries; doc++){
     double weight = document_score_array[doc];
 /* jmf */
     read_document_table_entry(&doc_entry, doc, db);  /* if this could be
 removed, we'd gain speed */
-/*	if (doc_entry.document_length) */
 	weight/=doc_entry.document_length;
     if(worst_weight_to_make_it < weight){
       /* merge it into the best_hits array. start at the bottom */
@@ -411,7 +386,6 @@ removed, we'd gain speed */
       best_hits_array[best_hit_number].end_character = doc_entry.end_character;
       best_hits_array[best_hit_number].document_length = doc_entry.document_length;
       best_hits_array[best_hit_number].number_of_lines = doc_entry.number_of_lines;
-      sprintf(best_hits_array[best_hit_number].date, "%d", doc_entry.date);
       read_filename_table_entry(doc_entry.filename_id, 
 				best_hits_array[best_hit_number].filename,
 				best_hits_array[best_hit_number].type,
@@ -467,7 +441,7 @@ double tmp;
 *score=tmp;
 *start=best_hits_array[current_best_hit].start_character;
 *end=best_hits_array[current_best_hit].end_character;
-*date=atoi(best_hits_array[current_best_hit].date);
+*date=(long)best_hits_array[current_best_hit].date;
 *length=best_hits_array[current_best_hit].document_length;
 *nlines=best_hits_array[current_best_hit].number_of_lines;
 strcpy(headline,best_hits_array[current_best_hit].headline);
@@ -515,18 +489,11 @@ char fn[256];
 
 
 #ifdef BOOLEANS
-/* tung, 10/93 */
-long word_id = 0;
-extern long number_of_qwords ;
-/* tung, 10/93 */
-
 static boolean   gLastAnd= false;
 static boolean   gLastNot= false;
-#endif /* BOOLEANS */
+#endif
 
 /* see irext.h for doc */
-/* returns -1 if error, 1 if word exists, 0 if not */
-
 long search_word(word,char_pos, line_pos, weight, doc_id, 
 		 word_pair, db)
      char *word; /* the word to be searched for */
@@ -559,7 +526,6 @@ long search_word(word,char_pos, line_pos, weight, doc_id,
   char *i;
   FILE *stream = NULL;
 
-
 #ifdef LITERAL
   long txt_pos, icnt, wcnt, pcnt;					/* 2/92 GS TLG */
   document_table_entry doc_entry;					/* 2/92 GS TLG */
@@ -571,12 +537,7 @@ long search_word(word,char_pos, line_pos, weight, doc_id,
   char prev_txt_filename[MAX_FILENAME_LEN + 1];				/* 2/92 GS TLG */
   char txt_type[MAX_TYPE_LEN + 1];					/* 2/92 GS TLG */
   long phraselen= 0, txt_pos_fix= 0;
-  char *document_section = NULL;     /* tung , 10/93 */
-  long document_section_len = 0;     /* tung , 10/93 */
-  long phrase_readed = 0;            /* tung , 10/93 */
-  long phrase_count = 0;             /* tung , 10/93 */
-  boolean phrase_found = false;      /* tung , 10/93 */
-#endif /* LITERAL */
+#endif
   
 /* do synonym conversion */
 
@@ -595,32 +556,7 @@ strncpy(word,newword,MAX_WORD_LENGTH);
   }
 #else
   stemmer(word); 
-#endif /* LITERAL */
-
-/* tung, 10/93 */
-#ifdef BOOLEANS
-  if(number_of_qwords > 0) {
-    if((weight!=LITERAL_FLAG) && IsOperator(word)) {
-      boolean_operations(word);
-      return(0);
-    }
-    if(search_result_array == NULL) {
-      search_result_array = 
-        (search_result_struct *)
-          s_malloc((size_t)(number_of_qwords * sizeof(search_result_struct))); 
-      word_id = 0;
-    }
-    if(strlen(word) == 1) {
-      search_result_array[word_id].number_of_hits = 0;
-      search_result_array[word_id].word_id = word_id;
-      save_word_id(word_id);
-      ++word_id;
-      return(0);
-    }
-  }
-#endif /* BOOLEANS */
-/* tung, 10/93 */
-  
+#endif
 
 #ifdef LITERAL
   if (weight==LITERAL_FLAG) {
@@ -628,7 +564,7 @@ strncpy(word,newword,MAX_WORD_LENGTH);
 /* printf("search_word: literal word is [%s]\n", word); */
     }
   else 
-#endif /* LITERAL */
+#endif
 #ifdef BOOLEANS
   if (strcmp(word,BOOLEAN_AND)==0) {  /* should be all lowercase cmp here */
     gLastAnd= true;
@@ -646,7 +582,7 @@ strncpy(word,newword,MAX_WORD_LENGTH);
   if (weight == BOOLEAN_NOT_FLAG) gLastNot= true;
 #else
      ;   /* if not LITERAL_FLAG */
-#endif /* BOOLEANS */
+#endif
 
   index_buffer = (char*)index_buffer_data;
 
@@ -667,7 +603,7 @@ strncpy(word,newword,MAX_WORD_LENGTH);
        more= (wordDelimiter(word[i]) == NOT_DELIMITER); 
 #else
        more= (isalnum(word[i]));
-#endif /* BIO */
+#endif
        }
     word1[i]= '\0';
     txt_pos_fix= strlen(word1) + 1;
@@ -684,7 +620,7 @@ strncpy(word,newword,MAX_WORD_LENGTH);
 #else
   index_file_block_number = 
     look_up_word_in_dictionary(word, &number_of_occurances, db);
-#endif /* PARTIALWORD */
+#endif
 
   current_best_hit = 0;  /* so that the best hits willstart from 0 */
 
@@ -695,7 +631,7 @@ strncpy(word,newword,MAX_WORD_LENGTH);
   if(index_file_block_number >= 0){
 #ifdef PARTIALWORD
    while(index_file_block_number > 0){  /* dgg, need 2nd loop here for multiple partwords */
-#endif /* PARTIALWORD */
+#endif
     stream = db->index_stream;
     
     while((not_full_flag != INDEX_BLOCK_NOT_FULL_FLAG) && 
@@ -709,11 +645,10 @@ strncpy(word,newword,MAX_WORD_LENGTH);
 		  (long)index_file_block_number); 
 #ifdef BOOLEANS
    gLastNot= gLastAnd= false;
-#endif /* BOOLEANS */  
+#endif  
 	  return(-1);
 	}
-
-      fread(index_buffer, INDEX_BLOCK_HEADER_SIZE, 1, stream);
+      read(fileno(stream),index_buffer,INDEX_BLOCK_HEADER_SIZE);
 
       ASSIGN(not_full_flag,
 	     INDEX_BLOCK_FLAG_SIZE,
@@ -731,7 +666,6 @@ strncpy(word,newword,MAX_WORD_LENGTH);
 
 /*
   this is equivalent, but slower:
-
       not_full_flag = read_bytes(INDEX_BLOCK_FLAG_SIZE, stream);
       index_file_block_number = read_bytes(NEXT_INDEX_BLOCK_SIZE, stream);
       index_block_size = read_bytes(INDEX_BLOCK_SIZE_SIZE, stream);
@@ -751,7 +685,7 @@ strncpy(word,newword,MAX_WORD_LENGTH);
 		  "reading from the index file failed");
 #ifdef BOOLEANS
    gLastNot= gLastAnd= false;
-#endif /* BOOLEANS */  
+#endif  
 	  return(-1);
 	}
       
@@ -769,7 +703,7 @@ strncpy(word,newword,MAX_WORD_LENGTH);
 		not_full_flag);
 #ifdef BOOLEANS
    gLastNot= gLastAnd= false;
-#endif /* BOOLEANS */  
+#endif  
 	return(-1);
       }
       /* printf("number of valid bytes: %ld\n", number_of_valid_entries); */
@@ -777,20 +711,6 @@ strncpy(word,newword,MAX_WORD_LENGTH);
       /* add the array to the document_score_array */
       number_of_valid_entries /= INDEX_ELEMENT_SIZE;
 
-
-/* tung, 10/93 */
-#ifdef BOOLEANS   
-      if((number_of_qwords > 0) && (search_result_array != NULL)) {
-        if(search_result_array[word_id].doc_ids_array == NULL) 
-          search_result_array[word_id].doc_ids_array =
-            (doc_descr_struct *)
-              s_malloc((size_t)(sizeof(doc_descr_struct) * number_of_valid_entries));
-        search_result_array[word_id].number_of_hits = number_of_valid_entries;
-      }
-#endif /* BOOLEANS */
-/* tung, 10/93 */
-
-
 /* ses - idf is a fist approximation to the inverse document freq. */
 /* what it actually is  is the inverse occurance frequency which says
 that the significance of a word is inversly proportional to the number
@@ -829,7 +749,7 @@ of times it occurs in the database */
 */
 /* printf("search_word: txtpos=%d, wgt=%d, did=%d\n", txt_pos, wgt, did); */
         }
-#endif /* LITERAL */
+#endif
 
 /* Commented out as suggested by Stan Isaacs at hp.com to come up with correct
  * weights when there are multiple documents in a file
@@ -852,7 +772,7 @@ of times it occurs in the database */
 		    "reading from the doc-id table failed");
 #ifdef BOOLEANS
    gLastNot= gLastAnd= false;
-#endif  /* BOOLEANS */
+#endif  
 	    return(-1);
 	  }
 
@@ -865,6 +785,7 @@ of times it occurs in the database */
                                       txt_filename, txt_type, NULL, db);  /* 2/92 GS TLG */
 /* printf("search_word: document is [%s]\n", txt_filename); */
             if (NULL == txt_stream) {
+
               if (probe_file(txt_filename)) {
                 txt_stream = s_fopen(txt_filename, "rb");
               }
@@ -876,9 +797,10 @@ of times it occurs in the database */
  	      }
  	      
               strcpy(prev_txt_filename, txt_filename);
-	    }
+             }
             else if (0 != strcmp(txt_filename, prev_txt_filename)) {
               s_fclose(txt_stream);
+
               if ( temp_txt_filename != NULL ) {
                 unlink(temp_txt_filename);
                 s_free(temp_txt_filename);
@@ -893,46 +815,20 @@ of times it occurs in the database */
  	        }
  	      }
               strcpy(prev_txt_filename, txt_filename);		/* 2/92 GS TLG */
-	    }
+              }
 
             txt_pos += doc_entry.start_character - txt_pos_fix;  /* dgg */
-
-            document_section_len = doc_entry.end_character - txt_pos;   /* tung, 10/93 */
             s_fseek(txt_stream, txt_pos, SEEK_SET);			/* 2/92 GS TLG */
-            document_section = 
-              (char*) s_malloc((size_t)((document_section_len+1)*sizeof(char))); /* tung, 10/93 */
-            fgets(document_section, document_section_len, txt_stream);   /* tung, 10/93 */
-            phrase_readed = 0;                                           /* tung, 10/93 */
-            phrase_readed += strlen(document_section);                   /* tung, 10/93 */
-            document_section = string_downcase(document_section);        /* tung, 10/93 */
-#if 0
-
             fread(phrase, 1L, phraselen, txt_stream);			/* 2/92 GS TLG */
 /* { phrase[phraselen]= '\0';
 printf("search_word: file phrase is [%s]\n", phrase); 
 } */
             if (0 != strncasecmp(word, phrase, phraselen))		/* 2/92 GS TLG */
               internal_weight = 0.0;					/* 2/92 GS TLG */
-#endif	/* 0 */
-
-            if (NULL == strstr(document_section, word)) {                    /* tung, 10/93 */
-              while(phrase_readed < document_section_len) {                  /* tung, 10/93 */
-                fgets(document_section, document_section_len, txt_stream);   /* tung, 10/93 */
-                phrase_readed += strlen(document_section);                   /* tung, 10/93 */
-                document_section = string_downcase(document_section);        /* tung, 10/93 */
-                if(strstr(document_section, word) != NULL)  {                /* tung, 10/93 */
-                  phrase_found = true;                                       /* tung, 10/93 */
-                  break;                                                     /* tung, 10/93 */
-                }                                                            /* tung, 10/93 */
-              }                                                              /* tung, 10/93 */
-              if(phrase_found == false)                                      /* tung, 10/93 */
-                internal_weight = 0.0;					     /* tung, 10/93 */
-              phrase_found = false;                                          /* tung, 10/93 */
-	    }
-            s_free(document_section);                                        /* tung, 10/93 */
           }
-        }								
-#endif /* LITERAL */
+        }								/* 2/92 GS TLG */
+
+#endif
 
 #ifdef BOOLEANS
 	if (gLastNot) {    
@@ -940,7 +836,7 @@ printf("search_word: file phrase is [%s]\n", phrase);
 /* 	printf("search_word: boolean 'not' scored\n"); */
 	    }
 	 else 
-#endif /* BOOLEANS */
+#endif
 	{
 	/* if(doc_id > 0) we are doing a relevant document */
 /*
@@ -949,36 +845,8 @@ printf("wgt: %ld, internal weight: %lf, idf: %lf occurances: %ld\n",
 fflush(stdout);
 */
         internal_weight*=idf; /* ses - for inverse doc. freq. */
-#ifndef BOOLEANS
 	document_score_array[internal_document_id] += 
 	  (doc_id) ? (internal_weight * RF_WEIGHTING) : internal_weight;
-#else
-/* tung, 10/93 */
-        if(number_of_qwords == 0) {
-          document_score_array[internal_document_id] += 
-            (doc_id) ? (internal_weight * RF_WEIGHTING) : internal_weight;
-	}
-        else {
-          if((number_of_qwords > 0) && (search_result_array != NULL)) {
-            if(weight == LITERAL_FLAG) {
-              if(document_score_array[internal_document_id] > 0) {
-                ((search_result_array[word_id]).doc_ids_array[phrase_count]).doc_id = internal_document_id;
-                ((search_result_array[word_id]).doc_ids_array[phrase_count]).score +=
-                  (doc_id) ? (internal_weight * RF_WEIGHTING) : internal_weight;
-                phrase_count++;
-                search_result_array[word_id].number_of_hits = phrase_count;
-              }
-            }
-            else {
-              ((search_result_array[word_id]).doc_ids_array[count]).doc_id = internal_document_id;
-              ((search_result_array[word_id]).doc_ids_array[count]).score +=
-                (doc_id) ? (internal_weight * RF_WEIGHTING) : internal_weight;
-            }
-          }
-        }
-#endif /* BOOLEANS */
-/* tung, 10/93 */
-        
 	}
 /*
 printf("Score array: %lf\n",document_score_array[internal_document_id]);
@@ -993,72 +861,51 @@ fflush(stdout);
   index_file_block_number = 
     look_up_partialword_in_dictionary(NULL, &number_of_occurances, db);
   }
-#endif /* PARTIALWORD */
+#endif
 
-/* tung, 10/93 */
-#ifdef BOOLEANS
-    if((number_of_qwords > 0) && (search_result_array != NULL)) {
-      save_word_id(word_id);
-      search_result_array[word_id].word_id = word_id;
-      ++word_id;
-    }
-#endif /* BOOLEANS */
-/* tung, 10/93 */
 
 #ifdef BOOLEANS
-   if(number_of_qwords == 0) {
-    for (count=0; count < db->doc_table_allocated_entries; count++) {  
-      if (!gLastAnd) { 							
-        prev_score_array[count] = document_score_array[count];		
-        }			 					
-      else {	   							
-        if ((document_score_array[count] == prev_score_array[count])	
+    for (count=0; count < db->doc_table_allocated_entries; count++) {   /* 12/91 GS TLG */
+      if (!gLastAnd) { 							/* 12/91 GS TLG */
+        prev_score_array[count] = document_score_array[count];		/* 12/91 GS TLG */
+        }			 					/* 12/91 GS TLG */
+      else {	   							/* 12/91 GS TLG */
+        if ((document_score_array[count] == prev_score_array[count])	/* 12/91 GS TLG */
             || (prev_score_array[count] == 0)) {
-	  document_score_array[count] = 0;				
-          prev_score_array[count] = 0;					
-          }								
+	  document_score_array[count] = 0;				/* 12/91 GS TLG */
+          prev_score_array[count] = 0;					/* 12/91 GS TLG */
+          }								/* 12/91 GS TLG */
         else {  
-	  prev_score_array[count] = document_score_array[count];	
-          }								
-      }									
-    }									
-  if (gLastAnd) printf("search_word: boolean `and' scored\n"); 
-  } 
-#endif /* BOOLEANS */
+	  prev_score_array[count] = document_score_array[count];	/* 12/91 GS TLG */
+          }								/* 12/91 GS TLG */
+      }									/* 12/91 GS TLG */
+    }									/* 12/91 GS TLG */
+/*  if (gLastAnd) printf("search_word: boolean `and' scored\n"); */
+#endif 
 
 #ifdef BOOLEANS
    gLastNot= gLastAnd= false;
 #endif /* BOOLEANS */
-    return(1); /* word present */
-}
+    return(0); 
+  }
   
   else if(0 == index_file_block_number){
     /* an error occurred on looking up the word */
 #ifdef BOOLEANS
    gLastNot= gLastAnd= false;
-#endif  /* BOOLEANS */
+#endif 
     return(-1);
   }
   
   else {				/* index_file_block_number is negative */
 #ifdef BOOLEANS
-/* tung, 10/93 */
-    if((number_of_qwords > 0) && (search_result_array != NULL)) {
-      save_word_id(word_id);
-      search_result_array[word_id].word_id = word_id;
-      search_result_array[word_id].number_of_hits = 0;
-      ++word_id;
-    }
-/* tung, 10/93 */
-    else {
-      if (gLastAnd) 
+if (gLastAnd) 
        for (count=0; count < db->doc_table_allocated_entries; count++) {
          document_score_array[count] = 0;                       
          prev_score_array[count] = 0;   
          } 
-    }
    gLastNot= gLastAnd= false;
-#endif  /* BOOLEANS */
+#endif 
     return(0);		/* word not present */
     }
 }
@@ -1068,22 +915,12 @@ fflush(stdout);
 long finished_search_word(db)
      database *db;
 { 
-#ifdef BOOLEANS
-  long number_of_hits; /* tung, 10/93 */
-#endif /* BOOLEANS */
 
 #ifdef BOOL
   if (currentQuery != NULL)
     return; /* do nothing for boolean */
 #endif /* def BOOL */
 
-/* tung, 10/93 */
-#ifdef BOOLEANS
-  if((number_of_qwords > 0) && (search_result_array != NULL))
-    number_of_hits = retriev_result(db->doc_table_allocated_entries);
-#endif /* BOOLEANS */
-/* tung, 10/93 */
-
   /* check the document_score_array */
   if(document_score_array_len < db->doc_table_allocated_entries)
     make_document_score_array(db->doc_table_allocated_entries);
@@ -1095,4 +932,3 @@ long finished_search_word(db)
   return(0);
 }
 
-
