@@ -319,15 +319,8 @@ long response_buffer_length;
  * to those trying to modify the transport code to use non-UNIX streams:
  *  This is the function to modify!
  */
-
-#ifdef LINUX
-long read_from_stream(stream,buf,nbytes)
-FILE *stream;		/* this is the stream */
-#else
 long read_from_stream(d,buf,nbytes)
-long d;
-#endif /* LINUX */
-
+long d;				/* this is the stream */
 char *buf;
 long nbytes;
 {
@@ -336,13 +329,7 @@ long nbytes;
   long totalRead = 0;		/* paranoia */
 
   while (toRead > 0){
-
-#ifdef LINUX
-    didRead = fread (buf, sizeof(char), toRead, stream);
-#else
     didRead = read (d, buf, toRead);
-#endif /* LINUX */
-
     if(didRead == -1)		/* error*/
       return(-1);
     if(didRead == 0)		/* eof */
@@ -385,24 +372,15 @@ long response_buffer_length;
   /* read for the first '0' */
 
   while(1){
-
-#ifdef LINUX
-    if(0 > read_from_stream(connection, response_message, 1))
-#else
     if(0 > read_from_stream(fileno(connection), response_message, 1))
-#endif /* LINUX */
-
       return 0;
     if('0' == response_message[0])
       break;
   }
 
-#ifdef LINUX
-  if(0 > read_from_stream(connection, response_message + 1, HEADER_LENGTH - 1))
-#else
-  if(0 > read_from_stream(fileno(connection), response_message + 1, HEADER_LENGTH - 1))
-#endif /* LINUX */
-
+  if(0 > read_from_stream(fileno(connection), 
+				  response_message + 1, 
+				  HEADER_LENGTH - 1))
     return 0;
 
   readWAISPacketHeader(response_message, &header);
@@ -422,26 +400,19 @@ long response_buffer_length;
 	 and return 0 */
       long i;
       for(i = 0; i < response_length; i++){
-
-#ifdef LINUX
-	read_from_stream(connection, response_message + HEADER_LENGTH, 1);
-#else
-	read_from_stream(fileno(connection), response_message + HEADER_LENGTH, 1);
-#endif /* LINUX */
-
+	read_from_stream(fileno(connection), 
+			 response_message + HEADER_LENGTH,
+			 1);
+/*	fread(response_message + HEADER_LENGTH, 1, 1, connection); */
       }
       return(0);
     }
   }
-
-#ifdef LINUX
-  if(0 > read_from_stream(connection, response_message + HEADER_LENGTH,
+  if(0 > read_from_stream(fileno(connection), 
+				  response_message + HEADER_LENGTH,
 				  response_length))
-#else
-  if(0 > read_from_stream(fileno(connection), response_message + HEADER_LENGTH,
-				  response_length))
-#endif /* LINUX */
-
+/*  if(0 > fread(response_message + HEADER_LENGTH,
+	       1, response_length, connection)) */
     return 0;
   return(response_length);
 }
