@@ -24,32 +24,14 @@ static char *RCSid = "$Header: /archives/stelar/src/freeWAIS/freeWAIS-0.2/ir/RCS
  * Revision 1.5  93/07/21  18:53:04  warnock
  * Renamed from irbuild.c
  * Added STELAR-specific patches
- *
- * $Log: irbuild.c,v $
- * Revision 1.8  1993/10/12  11:18:25  pfeifer
- * Added stopword file for document style bibdb
  * 
  * Revision 1.1  93/07/19  16:30:22  warnock
  * Initial revision
- *
- * Revision 1.7  1993/09/22  16:09:13  pfeifer
- * What have i done ?
- *
+ * 
  * Revision 1.4  93/07/01  19:40:31  warnock
  * Added prototype for function double
- *
- * Revision 1.6  1993/06/04  10:23:15  pfeifer
- * Pachtlevel BIBDB
  * 
  * Revision 1.3  93/02/16  17:07:49  freewais
- *
- * Revision 1.5  1993/06/02  18:29:00  pfeifer
- * Added code for local formats
- *
- * Revision 1.4  1993/06/01  14:05:54  pfeifer
- * Added code for soundex/phonix indexing and retrieval
- *
- * Revision 1.3  1993/02/16  17:07:49  freewais
  * added AT&T patches for keyword list
  * 
  * Revision 1.2  1993/02/16  15:32:21  freewais
@@ -151,7 +133,6 @@ double compare();
 
 extern char *keyword[50], *descript[1000];
 extern short nKeys, nDesLines;
-extern double compare();
 
 /* for reporting errors, in WAIStation it is defined in CRetrievalApp.c */
 
@@ -171,7 +152,6 @@ char *command;
   fprintf(stderr,"          [-l log_level] /* set log level.  0 means log nothing,\n");
   fprintf(stderr,"                            10 [the default] means log everything */\n");
   fprintf(stderr,"          [-v] /* print the version of the software */\n");
-  fprintf(stderr,"          [-filter process] /* use an external document parser */\n");
   fprintf(stderr,"          [-stdin] /* read file names from stdin */\n");
   fprintf(stderr,"          [-pos | -nopos] /* include (don't include - default) word position information /*\n");
   fprintf(stderr,"          [-nopairs | -pairs] /* don't include (or include - default) word pairs /*\n");
@@ -202,7 +182,6 @@ char *command;
   fprintf(stderr,"           | filename /* uses only the filename part of the pathname for the title */\n");
   fprintf(stderr,"           | ftp /* special type for FTP files.  First line of file is headline */\n");
   fprintf(stderr,"           | gif /* gif files, only indexes the filename */\n");
-  fprintf(stderr,"           | html /* html */\n");
   fprintf(stderr,"           | irg /* internet resource guide */\n");
   fprintf(stderr,"           | jargon /* Jargon File 2.9.8 format*/\n");
   fprintf(stderr,"           | mail_digest /* standard internet mail digest format */\n");
@@ -216,12 +195,6 @@ char *command;
   fprintf(stderr,"           | pict /* pict files, only indexes the filename */\n");
   fprintf(stderr,"           | ps /* postscript format */\n");
   fprintf(stderr,"           | refer /* refer format */\n");
-#ifdef BIBDB
-  fprintf(stderr,"           | irlist           /* irlist mail or rmail or both */\n");  
-  fprintf(stderr,"           | formfeed         /* entries separated by a formfeed */\n");
-  fprintf(stderr,"           | bibdb            /* steve file entries separated by a formfeed */\n");
-  fprintf(stderr,"           | bibinf           /* bibinf entries separated by an empty line */\n");
-#endif
   fprintf(stderr,"           | rn /* netnews saved by the [rt]?rn newsreader */\n");
   fprintf(stderr,"           | server /* server structures for the dir of servers */\n");
 #ifdef NeXT
@@ -229,12 +202,6 @@ char *command;
 #endif /* def NeXT */
   fprintf(stderr,"           | tiff /* tiff files, only indexes the filename */\n");
   fprintf(stderr,"           | URL what-to-trim what-to-add /* URL */\n");
-  fprintf(stderr,"           | object /* a structured object*/\n");
-  fprintf(stderr,"           | inriadoc /* INRIA library catalog */\n");
-  fprintf(stderr,"           | paradoc /* INRIA library catalog para-mode */\n ");
-  fprintf(stderr,"           | fortran /* Fortran files,needs also -filter */\n");
-  fprintf(stderr,"           | mime /* Like mail */\n");
-
 #ifdef BIO
   fprintf(stderr,"           | genbank  /* GenBank flatfile format */\n");
   fprintf(stderr,"           | embl     /* EMBL flatfile format */\n");
@@ -246,22 +213,16 @@ char *command;
   fprintf(stderr,"           | flybase  /* Drosophila Ashburner data files */\n");
   fprintf(stderr,"           | flystock  /* Drosophila stock lists */\n");
   fprintf(stderr,"           | din      /* Drosophila Info. Newsletter */\n");
-#endif
-#ifdef SOUND
-  fprintf(stderr,"           | oneline_phonix   /* Phonebooks PHONIX */\n");
-  fprintf(stderr,"           | oneline_soundex  /* Phonebooks SOUNDEX */\n");
 #endif
   fprintf(stderr,"           | listserv_digest /* standard internet mail digest format */\n");
-#ifdef AAS
-  fprintf(stderr,"           | AAS_abstract /* AAS meeting abstracts using AAS LaTeX macros */\n");
-#endif /* AAS */
 #ifdef STELAR
+  fprintf(stderr,"           | AAS_abstract /* AAS meeting abstracts using AAS LaTeX macros */\n");
   fprintf(stderr,"           | stelar /* stelar abstracts - third line is hl */\n");
 #endif /* STELAR */
   fprintf(stderr,"          ] filename filename ...\n");
 }
 
-/* char *log_file_name = NULL; */
+char *log_file_name = NULL;
 FILE *logfile;
 
 extern char* keywords;           /* used in irtfiles.c */
@@ -302,9 +263,6 @@ char *argv[];
   long hashtable_size = 1L<<16;
   long flush_after_n_words = 300000;
   char *command_name;
-  char *filter_name = NULL;
-  FILE *filter_process_in = NULL;
-  FILE *filter_process_out = NULL;
 
   dataopsrec	dataops;    
   /*-------------   these go into dataops   
@@ -323,7 +281,6 @@ char *argv[];
   dataops.date_function= NULL;
   dataops.finish_header_function= NULL;
   dataops.type= "TEXT";
-  dataops.indextype= NULL;
   dataops.multitype=NULL;
   dataops.addseparatorwords= false;
   dataops.extraheaderweight= true;
@@ -389,9 +346,6 @@ char *argv[];
 	exit(0);
       	}
       strcpy(gDelimiters, next_argument);
-      dataops.wordDelimiter = wordbreak_user;
-      wordDelimiter = wordbreak_user;
-      printf("Delimiters used in index: %s\n\n",gDelimiters);
       } 
 #endif
 
@@ -445,11 +399,6 @@ char *argv[];
 	panic("The -cmmem argument should not be less than 1 and less than 100");
       if(cm_mem_percent > 100)
 	panic("Warning: The -cmmem parameter was %ld%%. It should be between 1-100.", cm_mem_percent);
-    }
-       else if(0 == strcmp("-filter", next_argument)){
-       if(NULL == (next_argument = next_arg(&argc, &argv)))
-       panic("Expected the name of a program to use to find keywords");
-       filter_name=next_argument;
     }
     else if(0 == strcmp("-grow", next_argument)){
       if(NULL == (next_argument = next_arg(&argc, &argv)))
@@ -488,7 +437,6 @@ char *argv[];
 	panic("Expected a file type");
       typename = next_argument;
       dataops.type = next_argument;
-      fprintf(stderr,"waisindex: setting type to %s\n", next_argument);
       dataops.finish_header_function = filename_finish_header_function;
     }
 
@@ -702,15 +650,13 @@ char *argv[];
   	dataops.date_function = listserv_date_function;
   	dataops.finish_header_function = listserv_finish_header_function;
       }
-#ifdef AAS
+#ifdef STELAR
       else if(0 == strcmp("AAS_abstract", next_argument)){
  	typename = next_argument;
 	dataops.separator_function = aasab_separator_function;
  	dataops.header_function = aasab_header_function;
  	dataops.finish_header_function = aasab_finish_header_function;
       }
-#endif /* AAS */
-#ifdef STELAR
       else if(0==strcmp("stelar",next_argument)){
         dataops.type="TEXT";
         typename=next_argument;
@@ -775,57 +721,6 @@ char *argv[];
 	dataops.date_function = mail_date_function;
 	dataops.finish_header_function = mail_finish_header_function;
       }
-#ifdef BIBDB
-      else if(0 == strcmp("irlist", next_argument)){
-	typename = next_argument;
-	dataops.type = "TEXT";
-	dataops.separator_function = irlist_separator_function;
-	dataops.header_function = irlist_header_function;
-	dataops.date_function = irlist_date_function;
-	dataops.finish_header_function = mail_finish_header_function;
-      }
-      /* formfeed-separated items , Intro to Algorithms buglist, etc */
-      else if(0 == strcmp("formfeed", next_argument)){
-	typename = next_argument;
-	if (!dataops.type || (strlen(dataops.type)==0)) {
-          if (dataops.type)
-            fprintf(stderr, "irbuild: overwriting type %s\n", dataops.type);
-          dataops.type = "TEXT";
-        } else {
-          fprintf(stderr, "irbuild: using type %s\n", dataops.type);
-        }
-	dataops.separator_function = formfeed_separator_function;
-	dataops.header_function = dash_header_function;
-	dataops.finish_header_function = dash_finish_header_function;
-      }
-      /* formfeed-separated items , steve files */
-      else if(0 == strcmp("bibdb", next_argument)){
-	typename = next_argument;
-	if (!dataops.type || (strlen(dataops.type)==0)) {
-          if (dataops.type)
-            fprintf(stderr, "irbuild: overwriting type %s\n", dataops.type);
-          dataops.type = "TEXT";
-        } else {
-          fprintf(stderr, "irbuild: using type %s\n", dataops.type);
-          stop_list_file("bibdb.stop");
-        }
-	dataops.separator_function = bibdb_separator_function;
-	dataops.header_function = bibdb_header_function;
-	dataops.date_function = bibdb_date_function;
-	dataops.finish_header_function = bibdb_finish_header_function;
-      }
-      /* formfeed-separated items, bibinbf */
-      else if(0 == strcmp("bibinf", next_argument)){
-	typename = next_argument;
-        dataops.type = "TEXT";
-        dataops.separator_function = bibinf_separator_function;
-        dataops.header_function = bibinf_header_function;
-#ifdef SIMPLE_BIBINF
-        dataops.date_function = bibinf_date_function;
-#endif
-        dataops.finish_header_function = bibinf_finish_header_function;
-      }
-#endif
       else if(0 == strcmp("emacsinfo", next_argument)){
 	typename = next_argument;
 	dataops.type = "TEXT";
@@ -883,14 +778,6 @@ char *argv[];
 	typename = next_argument;
 	dataops.finish_header_function = filename_finish_header_function;
       }
-      /* html format */
-      else if(0 == strcmp("html", next_argument)){
-        dataops.type = "HTML";
-        typename = next_argument;
-        dataops.separator_function = html_separator_function;
-        dataops.header_function = html_header_function;
-        dataops.finish_header_function = html_finish_header_function;
-      }
       else if(0 == strcmp("irg", next_argument)){
 	typename = next_argument;
 	dataops.type = "TEXT";
@@ -990,38 +877,6 @@ char *argv[];
 	dataops.finish_header_function = filename_finish_header_function;
 	index_contents = false;
       }
-      else if(0== strcmp("object", next_argument)) {
-        dataops.type = "OBJECT";
-        typename = next_argument;
-      }
-      else if(0 == strcmp("inriadoc", next_argument)){
-        typename = next_argument;
-        dataops.type = "TEXT";
-        dataops.separator_function = NULL;
-        dataops.header_function = inriadoc_header_function;
-        dataops.date_function = NULL;
-        dataops.finish_header_function = inriadoc_finish_header_function;
-      }
-      else if(0 == strcmp("fortran", next_argument)){
-        typename = next_argument;
-        dataops.type = "FORTRAN";
-      }
-      else if(0 == strcmp("paradoc", next_argument)){
-        typename = next_argument;
-        dataops.type = "TEXT";
-        dataops.separator_function = para_separator_function;
-        dataops.header_function = inriadoc_header_function;
-        dataops.date_function = NULL;
-        dataops.finish_header_function = inriadoc_finish_header_function;
-      }
-      else if(0 == strcmp("mime", next_argument)){
-        typename = next_argument;
-        dataops.type = "MIME";
-        dataops.separator_function = mail_separator_function;
-        dataops.header_function = mail_header_function;
-        dataops.date_function = mail_date_function;
-        dataops.finish_header_function = mail_finish_header_function;
-      }
       /* BibTeX items */
       else if(0 == strcmp("bibtex", next_argument)){
 	dataops.type = "TEXT";
@@ -1052,24 +907,6 @@ char *argv[];
 	dataops.header_function = ziff_header_function;
 	dataops.finish_header_function = ziff_finish_header_function;
       }
-#ifdef SOUND
-      else if(0 == strcmp("oneline_soundex", next_argument)){
-	dataops.indextype = "SOUNDEX";
-        dataops.type = "TEXT";
-	typename = next_argument;
-	dataops.separator_function = one_line_separator_function;
-	dataops.header_function = one_line_header_function;
-	dataops.finish_header_function = one_line_finish_header_function;
-      }
-      else if(0 == strcmp("oneline_phonix", next_argument)){
-	dataops.indextype = "PHONIX";
-        dataops.type = "TEXT";
-	typename = next_argument;
-	dataops.separator_function = one_line_separator_function;
-	dataops.header_function = one_line_header_function;
-	dataops.finish_header_function = one_line_finish_header_function;
-      }
-#endif
       else{
 	panic("Don't recognize the '%s' type", next_argument);
       }
@@ -1154,54 +991,6 @@ char *argv[];
       hashtable_size = 1L<<18;
       flush_after_n_words = 1000000;
     }
-/* Set up the filter process, if needed */
-     /* We do this before initing the hash table to stop the fork copying a
-        load of rubbish*/
-   if(filter_name) {
-     int to_handles[2];
-     int from_handles[2];
-     int pid;
-     extern int errno;
-     if (pipe(to_handles) <0) {
-       panic("can't open to pipe");
-     }
-     if (pipe(from_handles) <0) {
-       panic("can't open from pipe");
-     }
-
-     if((pid = fork()) ==0) {
-
-       /* child */
-
-       close(0);
-       close(1);
-       close(2);
-       dup(to_handles[0]);
-       dup(from_handles[1]);         /* Set up standard input/output/error */
-       dup(from_handles[1]);
-       close(to_handles[0]);
-       close(to_handles[1]);
-       close(from_handles[0]);
-       close(from_handles[1]);
-
-       if(execl(filter_name,filter_name,NULL) == -1) {
-       exit(errno);
-       }
-       /*NOTREACHED*/
- }    
-     /* parent */
-
-    if (pid <0) {
-       panic("Couldn't fork");
-     }
-     close(to_handles[0]);
-     close(from_handles[1]);
-
-     filter_process_in=fdopen(to_handles[1],"w");
-     filter_process_out=fdopen(from_handles[0],"r");
-     waislog(WLOG_LOW, WLOG_INDEX, "Filter %s started (%d)",filter_name,pid);
-   }
-
     init_add_word(db, hashtable_size, flush_after_n_words);
   }
 
@@ -1218,19 +1007,9 @@ char *argv[];
     if(directoryp(next_argument)){
        if(traverse_directory){
 	 index_directory(next_argument, &dataops, db,
-			 check_for_text_file,
-			 adding_to_existing_index,
-			 word_positions, word_pairs,
-			 filter_process_in,filter_process_out);
-/*	 index_directory(next_argument,
-			 separator_function,
-			 header_function,
-			 date_function,
-			 finish_header_function,
-			 type, db,
 			 check_for_text_file,
 			 adding_to_existing_index, 
-			 word_positions, word_pairs, minwordlen); */
+			 word_positions, word_pairs);
        }
      }
     else{			/* not a directory */
@@ -1238,16 +1017,7 @@ char *argv[];
 	      "Indexing file: %s", next_argument);
       index_text_file(next_argument, &dataops, db, 
 		      check_for_text_file, adding_to_existing_index,
-		      word_positions, word_pairs,
-		      filter_process_in,filter_process_out);
-/*      index_text_file(next_argument,
-		      separator_function,
-		      header_function,
-		      date_function,
-		      finish_header_function,
-		      type, db, 
-		      check_for_text_file, adding_to_existing_index,
-		      word_positions, word_pairs, minwordlen); */
+		      word_positions, word_pairs);
     }
     if (read_files_from_stdin) {
       if (0 != (next_argument = fgets(data_filename, MAXPATHLEN, stdin))) {
@@ -1319,16 +1089,6 @@ export_database?pathname_name(index_filename):
   }
   if(make_catalog) build_catalog(db);
   closeDatabase(db);
-  /* wait for filter process to die, if there was one*/
-
-   if(filter_process_in) {
-     fprintf(filter_process_in,"Q\n");
-     fflush(filter_process_in);
-     fclose(filter_process_out);
-     fclose(filter_process_in);
-     waislog(WLOG_LOW, WLOG_INDEX, "Filter %s Exited (%ld)",filter_name,wait(0L));
-   }
-
   waislog(WLOG_MEDIUM, WLOG_INDEX, "Finished build");
   exit(0);
 }
