@@ -25,7 +25,7 @@
 #define USE_DIRENT
 #endif
 
-#if defined(USG) || defined(_IBMR2) || defined (ULTRIX) || defined (SOLARIS)
+#if defined(USG) || defined(_IBMR2)
 #ifndef NeXT
 #ifndef _SYS_DIRENT_INCLUDED
 #include <dirent.h>
@@ -34,16 +34,6 @@
 #endif /* ndef NeXT */
 #endif
 
-#ifdef LINUX
-#define USE_DIRENT
-#include <dirent.h>
-/* Seek to position POS on DIRP.  */
-extern void seekdir __P ((DIR * __dirp, __off_t __pos));
-
-/* Return the current position of DIRP.  */
-extern __off_t telldir __P ((DIR * __dirp));
-#endif
-
 #if defined(NeXT) || defined(BSD43)
 #include <sys/dir.h>	
 #define dirent direct
