@@ -2,9 +2,7 @@
 /* Copyright (c) CNIDR (see ../COPYRIGHT) */
 
 #include <stdio.h>
-#include <stdlib.h>
 
-int
 main(argc, argv)
 int argc;
 char **argv;
@@ -27,6 +25,4 @@ char **argv;
     else if (i++ < len)
       putchar(c);
   }
-  exit(0);
 }
-
